@@ -2,7 +2,7 @@
 ** dcat
 ** The  Sleuth Kit 
 **
-** $Date: 2005/04/27 18:09:35 $
+** $Date: 2005/09/02 23:34:02 $
 **
 ** Given an image , block number, and size, display the contents
 ** of the block to stdout.
@@ -14,49 +14,18 @@
 ** Copyright (c) 2002 Brian Carrier, @stake Inc.  All rights reserved
 **
 ** TCTUTILs
-** Brian Carrier [carrier@cerias.purdue.edu]
 ** Copyright (c) 2001 Brian Carrier.  All rights reserved
 **
-** Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are
-** met:
 **
-** 1. Redistributions of source code must retain the above copyright notice,
-**    this list of conditions and the following disclaimer.
-** 2. Redistributions in binary form must reproduce the above copyright
-**    notice, this list of conditions and the following disclaimer in the
-**    documentation and/or other materials provided with the distribution.
-** 3. The name of the author may not be used to endorse or promote
-**    products derived from this software without specific prior written
-**    permission.     
-**
-**
-** THIS SOFTWARE IS NOT AFFILIATED WITH PURDUE UNIVERSITY OR THE CENTER FOR
-** EDUCATION IN INFORMATION ASSURANCE AND SECURITY (CERIAS) AND THEY BEAR
-** NO RESPONSIBILITY FOR ITS USE OR MISUSE.
-**
-**
-** THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
-** WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-** MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
-** 
-** IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
-** INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-** (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR 
-** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-** OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-** ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+** This software is distributed under the Common Public License 1.0
 **
 */
 
-#include "fs_lib.h"
+#include "libfstools.h"
 
 #define DLS_TYPE "dls"
 #define RAW_STR "raw"
 
-FILE *logfp;
-
 void
 usage()
 {
@@ -102,7 +71,9 @@ main(int argc, char **argv)
     char format = 0, *cp, *imgtype = NULL, *imgoff = NULL;
     IMG_INFO *img;
     extern int optind;
+
     progname = argv[0];
+    setlocale(LC_ALL, "");
 
     while ((ch = getopt(argc, argv, "af:hi:o:su:vVw")) > 0) {
 	switch (ch) {
@@ -136,7 +107,6 @@ main(int argc, char **argv)
 	    break;
 	case 'v':
 	    verbose++;
-	    logfp = stderr;
 	    break;
 	case 'V':
 	    print_version(stdout);
