@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit
 **
-** $Date: 2005/04/27 18:09:35 $
+** $Date: 2005/09/02 19:53:27 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -28,11 +28,9 @@
  *	Yorktown Heights, NY 10598, USA
  */
 
-#include "fs_lib.h"
+#include "libfstools.h"
 
 
-FILE *logfp;
-
 /* atoblock - convert string to block number */
 
 DADDR_T
@@ -99,8 +97,8 @@ main(int argc, char **argv)
     char *imgtype = NULL, *imgoff = NULL, *cp, *dash;
     IMG_INFO *img;
 
-
     progname = argv[0];
+    setlocale(LC_ALL, "");
 
     while ((ch = getopt(argc, argv, "bef:i:lo:svV")) > 0) {
 	switch (ch) {
@@ -132,7 +130,6 @@ main(int argc, char **argv)
 	    break;
 	case 'v':
 	    verbose++;
-	    logfp = stderr;
 	    break;
 	case 'V':
 	    print_version(stdout);
