@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/09/02 19:53:27 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -28,7 +28,7 @@
  *	Yorktown Heights, NY 10598, USA
  */
 
-#include "fs_lib.h"
+#include "libfstools.h"
 
 
 
@@ -89,7 +89,7 @@ static uint8_t
 print_block(FS_INFO * fs, DADDR_T addr, char *buf, int flags, void *ptr)
 {
     if (verbose)
-	fprintf(logfp, "write block %" PRIuDADDR "\n", addr);
+	fprintf(stderr, "write block %" PRIuDADDR "\n", addr);
 
     if (fwrite(buf, fs->block_size, 1, stdout) != 1)
 	error("write stdout: %m");
@@ -110,7 +110,7 @@ slack_file_act(FS_INFO * fs, DADDR_T addr, char *buf,
 {
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"slack_file_act: Remaining File:  %" PRIuOFF
 		"  Buffer: %u\n", flen, size);
 
@@ -139,7 +139,7 @@ slack_inode_act(FS_INFO * fs, FS_INODE * fs_inode, int flags, void *ptr)
 {
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"slack_inode_act: Processing meta data: %" PRIuINUM "\n",
 		fs_inode->addr);
 
