@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/09/02 19:53:27 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -63,7 +63,7 @@ ext2fs_group_load(EXT2FS_INFO * ext2fs, EXT2_GRPNUM_T grp_num)
 
     if (verbose) {
 	FS_INFO *fs = (FS_INFO *) & ext2fs->fs_info;
-	fprintf(logfp,
+	fprintf(stderr,
 		"\tgroup %" PRI_EXT2GRP ": %" PRIu16 "/%" PRIu16
 		" free blocks/inodes\n", grp_num, getu16(fs,
 							 gd->
@@ -81,10 +81,10 @@ ext2fs_print_map(UCHAR * map, int len)
 
     for (i = 0; i < len; i++) {
 	if (i > 0 && i % 10 == 0)
-	    putc('|', logfp);
-	putc(isset(map, i) ? '1' : '.', logfp);
+	    putc('|', stderr);
+	putc(isset(map, i) ? '1' : '.', stderr);
     }
-    putc('\n', logfp);
+    putc('\n', stderr);
 }
 
 
@@ -230,7 +230,7 @@ ext2fs_dinode_load(EXT2FS_INFO * ext2fs, INUM_T inum)
 
     ext2fs->dino_inum = inum;
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"%" PRIuINUM " m/l/s=%o/%d/%" PRIuOFF
 		" u/g=%d/%d macd=%lu/%lu/%lu/%lu\n",
 		inum, getu16(fs, dino->i_mode),
@@ -603,7 +603,7 @@ ext2fs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
 		INODE_TABLE_SIZE(ext2fs);
 
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"block_walk: loading group %" PRI_EXT2GRP
 			" dbase %" PRIuDADDR " bmap +%" PRIuDADDR
 			" imap +%" PRIuDADDR " inos +%" PRIuDADDR "..%"
@@ -703,7 +703,7 @@ ext2fs_file_walk_direct(FS_INFO * fs, DATA_BUF * buf[],
     if (addr > fs->last_block) {
 	if (flags & FS_FLAG_FILE_NOABORT) {
 	    if (verbose) {
-		fprintf(logfp,
+		fprintf(stderr,
 			"Invalid direct block address (too large): %"
 			PRIu32 "", addr);
 	    }
@@ -760,13 +760,13 @@ ext2fs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
     unsigned int n;
 
     if (verbose)
-	fprintf(logfp, "%s: level %d block %" PRIu32 "\n", myname, level,
+	fprintf(stderr, "%s: level %d block %" PRIu32 "\n", myname, level,
 		addr);
 
     if (addr > fs->last_block) {
 	if (flags & FS_FLAG_FILE_NOABORT) {
 	    if (verbose) {
-		fprintf(logfp,
+		fprintf(stderr,
 			"Invalid indirect block address (too large): %"
 			PRIu32 "", addr);
 	    }
@@ -809,7 +809,7 @@ ext2fs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	if (getu32(fs, (uint8_t *) & iaddr[n]) > fs->last_block) {
 	    if (flags & FS_FLAG_FILE_NOABORT) {
 		if (verbose) {
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "Invalid address in indirect list (too large): %"
 			    PRIu32 "", getu32(fs, (uint8_t *) & iaddr[n]));
 		}
@@ -867,7 +867,8 @@ ext2fs_file_walk(FS_INFO * fs, FS_INODE * inode, uint32_t type,
 
 
     if (verbose)
-	fprintf(logfp, "ext2fs_file_walk: Processing file %" PRIuINUM "\n",
+	fprintf(stderr,
+		"ext2fs_file_walk: Processing file %" PRIuINUM "\n",
 		inode->addr);
 
     /*
@@ -960,12 +961,15 @@ ext2fs_fsstat(FS_INFO * fs, FILE * hFile)
 	    getu64(fs, &sb->s_uuid[8]), getu64(fs, &sb->s_uuid[0]));
 
     tmptime = getu32(fs, sb->s_wtime);
-    fprintf(hFile, "\nLast Written at: %s", asctime(localtime(&tmptime)));
+    fprintf(hFile, "\nLast Written at: %s",
+	    (tmptime > 0) ? asctime(localtime(&tmptime)) : "empty");
     tmptime = getu32(fs, sb->s_lastcheck);
-    fprintf(hFile, "Last Checked at: %s", asctime(localtime(&tmptime)));
+    fprintf(hFile, "Last Checked at: %s",
+	    (tmptime > 0) ? asctime(localtime(&tmptime)) : "empty");
 
     tmptime = getu32(fs, sb->s_mtime);
-    fprintf(hFile, "\nLast Mounted at: %s", asctime(localtime(&tmptime)));
+    fprintf(hFile, "\nLast Mounted at: %s",
+	    (tmptime > 0) ? asctime(localtime(&tmptime)) : "empty");
 
     /* State of the file system */
     if (getu16(fs, sb->s_state) & EXT2FS_STATE_VALID)
@@ -1701,7 +1705,8 @@ ext2fs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 
     fs->file_walk(fs, fs_inode, 0, 0,
 		  (FS_FLAG_FILE_AONLY | FS_FLAG_FILE_META |
-		   FS_FLAG_FILE_NOID), print_addr_act, (void *) &print);
+		   FS_FLAG_FILE_NOID | FS_FLAG_FILE_NOABORT),
+		  print_addr_act, (void *) &print);
 
     if (print.idx != 0)
 	fprintf(hFile, "\n");
@@ -1794,9 +1799,9 @@ ext2fs_open(IMG_INFO * img_info, unsigned char ftype, uint8_t test)
     if (verbose) {
 	if (getu32(fs, ext2fs->fs->s_feature_ro_compat) &
 	    EXT2FS_FEATURE_RO_COMPAT_SPARSE_SUPER)
-	    fprintf(logfp, "File system has sparse super blocks\n");
+	    fprintf(stderr, "File system has sparse super blocks\n");
 
-	fprintf(logfp, "First data block is %" PRIu32 "\n",
+	fprintf(stderr, "First data block is %" PRIu32 "\n",
 		getu32(fs, ext2fs->fs->s_first_data_block));
     }
 
@@ -1842,7 +1847,7 @@ ext2fs_open(IMG_INFO * img_info, unsigned char ftype, uint8_t test)
     if (ext2fs->inode_size < sizeof(ext2fs_inode)) {
 	ext2fs->inode_size = sizeof(ext2fs_inode);
 	if (verbose)
-	    fprintf(logfp, "SB inode size is too small, using default");
+	    fprintf(stderr, "SB inode size is too small, using default");
     }
 
 
@@ -1922,7 +1927,7 @@ ext2fs_open(IMG_INFO * img_info, unsigned char ftype, uint8_t test)
      * Print some stats.
      */
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"inodes %" PRIu32 " root ino %" PRIuINUM " blocks %" PRIu32
 		" blocks/group %" PRIu32 "\n", getu32(fs,
 						      ext2fs->fs->
