@@ -3,43 +3,16 @@
 ** ext2fs_journal
 ** The Sleuth Kit 
 **
-** $Date: 2005/06/13 19:27:16 $
+** $Date: 2005/09/02 23:34:02 $
 **
 ** Journaling code for EXT3FS image
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2004-2005 Brian Carrier.  All rights reserved 
 **
-** Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are
-** met:
 **
-** 1. Redistributions of source code must retain the above copyright notice,
-**    this list of conditions and the following disclaimer.
-** 2. Redistributions in binary form must reproduce the above copyright
-**    notice, this list of conditions and the following disclaimer in the
-**    documentation and/or other materials provided with the distribution.
-** 3. The name of the author may not be used to endorse or promote
-**    products derived from this software without specific prior written
-**    permission.     
+** This software is distributed under the Common Public License 1.0
 **
-**
-**
-** THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
-** WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-** MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
-**
-** THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
-** WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-** MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
-**
-** IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
-** INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-** (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR
-** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-** OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-** ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
 
 #include "fs_tools.h"
@@ -106,7 +79,7 @@ ext2fs_jopen(FS_INFO * fs, INUM_T inum)
 		  load_sb_action, NULL);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"journal opened at inode %" PRIuINUM " bsize: %" PRIu32
 		" First JBlk: %" PRIuDADDR " Last JBlk: %" PRIuDADDR "\n",
 		inum, jinfo->bsize, jinfo->first_block, jinfo->last_block);
