@@ -2,7 +2,7 @@
 ** fatfs
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/10/13 04:15:21 $
 **
 ** Content and meta data layer support for the FAT file system 
 **
@@ -12,11 +12,17 @@
 ** TASK
 ** Copyright (c) 2002 Brian Carrier, @stake Inc.  All rights reserved
 **
+**
+** This software is distributed under the Common Public License 1.0
+**
+** Unicode added with support from I.D.E.A.L. Technology Corp (Aug '05)
+**
 */
 
 #include "fs_tools.h"
 #include "fs_types.h"
 #include "fatfs.h"
+#include "fs_unicode.h"
 
 
 
@@ -175,7 +181,7 @@ getFAT(FATFS_INFO * fatfs, DADDR_T clust)
 
 /* This produces way too many entries 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_getFAT: Lookup Cluster %" PRIuDADDR " to %" PRIu32
 		"\n", clust, retval);
 */
@@ -218,7 +224,6 @@ is_83_name(fatfs_dentry * de)
     /* The IS_NAME macro will fail if the value is 0x05, which is only
      * valid in name[0], similarly with '.' */
     if ((de->name[0] != FATFS_SLOT_E5) && (de->name[0] != '.') &&
-	(de->name[0] != FATFS_SLOT_DELETED) &&
 	(FATFS_IS_83_NAME(de->name[0]) == 0))
 	return 0;
 
@@ -244,34 +249,6 @@ is_83_name(fatfs_dentry * de)
 	return 1;
 }
 
-/*
- * Check if the given lfn entry has a valid long name
- * We are only looking at the ASCII equivalent of UNICODE
- *
- * The char set for lfn is larger than that of 8.3
- *
- * return 1 if valid name, 0 if not
- */
-static uint8_t
-is_lfn_name(fatfs_dentry_lfn * de)
-{
-    int i;
-    if (!de)
-	return 0;
-
-    for (i = 0; i < 10; i += 2)
-	if (FATFS_IS_LFN_NAME(de->part1[i]) == 0)
-	    return 0;
-    for (i = 0; i < 12; i += 2)
-	if (FATFS_IS_LFN_NAME(de->part2[i]) == 0)
-	    return 0;
-    for (i = 0; i < 4; i += 2)
-	if (FATFS_IS_LFN_NAME(de->part3[i]) == 0)
-	    return 0;
-
-    return 1;
-}
-
 
 /**************************************************************************
  *
@@ -310,7 +287,7 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
 	      end_blk);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_block_walk: Block Walking %" PRIuDADDR " to %"
 		PRIuDADDR "\n", start_blk, end_blk);
 
@@ -322,7 +299,7 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
 	&& ((flags & FS_FLAG_DATA_ALLOC) == FS_FLAG_DATA_ALLOC)) {
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fatfs_block_walk: Walking non-data area (pre %"
 		    PRIuDADDR "\n", fatfs->firstclustsect);
 
@@ -388,7 +365,7 @@ fatfs_block_walk(FS_INFO * fs, DADDR_T start_blk, DADDR_T end_blk,
     data_buf = data_buf_alloc(fs->block_size * fatfs->csize);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_block_walk: Walking data area blocks (%" PRIuDADDR
 		" to %" PRIuDADDR ")\n", addr, end_blk);
 
@@ -494,7 +471,7 @@ dos2unixtime(uint16_t date, uint16_t time)
 
     if (-1 == ret) {
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "dos2unixtime: Error running mktime(): %d:%d:%d %d/%d/%d",
 		    ((time & FATFS_HOUR_MASK) >> FATFS_HOUR_SHIFT),
 		    ((time & FATFS_MIN_MASK) >> FATFS_MIN_SHIFT),
@@ -505,7 +482,6 @@ dos2unixtime(uint16_t date, uint16_t time)
 	return 0;
     }
 
-
     return ret;
 }
 
@@ -616,30 +592,60 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
     }
 
     if ((in->attrib & FATFS_ATTR_LFN) == FATFS_ATTR_LFN) {
-	int a, i;
 	fatfs_dentry_lfn *lfn = (fatfs_dentry_lfn *) in;
-	i = 0;
 
-	for (a = 0; a < 10; a += 2) {
-	    if ((lfn->part1[a] != 0) && (lfn->part1[a] != 0xff)) {
-		fs_inode->name->name[i++] = lfn->part1[a];
-	    }
+	/* Convert the UTF16 to UTF8 */
+	UTF8 *name8 = (UTF8 *) fs_inode->name->name;
+	UTF16 *name16 = (UTF16 *) lfn->part1;
+
+	int retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				    (UTF16 *) & lfn->part1[10],
+				    &name8,
+				    (UTF8 *) ((uintptr_t) fs_inode->name->
+					      name + 512),
+				    lenientConversion);
+
+	if (retVal != conversionOK) {
+	    error
+		("fatfs_dinode_copy: Error converting FAT LFN (1) to UTF8: %d",
+		 retVal);
 	}
-	for (a = 0; a < 12; a += 2) {
-	    if ((lfn->part2[a] != 0) && (lfn->part2[a] != 0xff)) {
-		fs_inode->name->name[i++] = lfn->part2[a];
-	    }
+
+	name16 = (UTF16 *) lfn->part2;
+	retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				(UTF16 *) & lfn->part2[12],
+				&name8,
+				(UTF8 *) ((uintptr_t) fs_inode->name->
+					  name + 512), lenientConversion);
+
+	if (retVal != conversionOK) {
+	    error
+		("fatfs_dinode_copy: Error converting FAT LFN (2) to UTF8: %d",
+		 retVal);
 	}
-	for (a = 0; a < 4; a += 2) {
-	    if ((lfn->part3[a] != 0) && (lfn->part3[a] != 0xff)) {
-		fs_inode->name->name[i++] = lfn->part3[a];
-	    }
+
+	name16 = (UTF16 *) lfn->part3;
+	retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				(UTF16 *) & lfn->part3[4],
+				&name8,
+				(UTF8 *) ((uintptr_t) fs_inode->name->
+					  name + 512), lenientConversion);
+
+	if (retVal != conversionOK) {
+	    error
+		("fatfs_dinode_copy: Error converting FAT LFN (3) to UTF8: %d",
+		 retVal);
 	}
-	fs_inode->name->name[i++] = '\0';
+
+	/* Make sure it is NULL Terminated */
+	if ((uintptr_t) name8 > (uintptr_t) fs_inode->name->name + 512)
+	    fs_inode->name->name[511] = '\0';
+	else
+	    *name8 = '\0';
     }
     else if ((in->attrib & FATFS_ATTR_VOLUME) == FATFS_ATTR_VOLUME) {
-	int a, i;
-	i = 0;
+	int a, i = 0;
+
 	for (a = 0; a < 8; a++) {
 	    if ((in->name[a] != 0x00) && (in->name[a] != 0xff))
 		fs_inode->name->name[i++] = in->name[a];
@@ -649,7 +655,6 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 		fs_inode->name->name[i++] = in->ext[a];
 	}
 	fs_inode->name->name[i] = '\0';
-
     }
     else {
 	int i;
@@ -713,7 +718,6 @@ fatfs_dinode_copy(FATFS_INFO * fatfs, FS_INODE * fs_inode,
 	 * that value 
 	 */
 	fs_inode->size = (OFF_T) (cnum * fatfs->csize * fatfs->ssize);
-
     }
 
     /* Use the allocation status of the sector to determine if the
@@ -811,10 +815,16 @@ fatfs_isdentry(FATFS_INFO * fatfs, fatfs_dentry * de)
     if (!de)
 	return 0;
 
-    /* LFN Do not have these values
-     */
+    /* LFN have their own checks, which are pretty weak since most
+     * fields are UTF16 */
     if ((de->attrib & FATFS_ATTR_LFN) == FATFS_ATTR_LFN) {
-	return is_lfn_name((fatfs_dentry_lfn *) de);
+	fatfs_dentry_lfn *de_lfn = (fatfs_dentry_lfn *) de;
+
+	if ((de_lfn->seq > (FATFS_LFN_SEQ_FIRST | 0x0f))
+	    && (de_lfn->seq != FATFS_SLOT_DELETED))
+	    return 0;
+
+	return 1;
     }
     else {
 	if (de->lowercase & ~(FATFS_CASE_LOWER_ALL))
@@ -847,10 +857,12 @@ fatfs_isdentry(FATFS_INFO * fatfs, fatfs_dentry * de)
 	    return 0;
 
 	return is_83_name(de);
+	//return 1;
     }
 }
 
 
+
 /**************************************************************************
  *
  * INODE WALKING
@@ -917,7 +929,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 	      end_inum);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_inode_walk: Inode Walking %" PRIuINUM " to %"
 		PRIuINUM "\n", start_inum, end_inum);
 
@@ -953,7 +965,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
     memset((char *) sect_alloc, 0, sizeof(*sect_alloc));
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_inode_walk: Walking directories to collect sector info\n");
 
     fatfs_dent_walk(fs, fs->root_inum,
@@ -1005,19 +1017,11 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 		      ": %m", sect);
 	    }
 
-	    /* if we know it is not part of a directory and it is not valid dentires,
-	     * then skip it */
-	    if ((isset(sect_alloc, sect) == 0) &&
-		(fatfs_isdentry(fatfs,
-				(fatfs_dentry *) fatfs->dinodes->data) ==
-		 0))
-		continue;
-
 	    /* get the base inode address of this sector */
 	    inum = FATFS_SECT_2_INODE(fatfs, sect);
 
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"fatfs_inode_walk: Processing sector %" PRIuDADDR
 			" (pre data area) starting at inode %" PRIuINUM
 			"\n", sect, inum);
@@ -1054,11 +1058,9 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 
 
 		/* Allocation status 
-		 * This is determined first by the sector allocation status
-		 * an then the dentry flag.  When a directory is deleted, the
-		 * contents are not always set to unallocated
+		 * This is determined by the name only since this
+		 * is the root directory
 		 */
-
 		myflags =
 		    ((dep->name[0] ==
 		      FATFS_SLOT_DELETED) ? FS_FLAG_META_UNALLOC :
@@ -1083,7 +1085,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 		fs_inode->flags = myflags;
 
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "fatfs_inode_walk: Directory Entry %" PRIuINUM
 			    " (%u) at sector %" PRIuDADDR "\n", inum, didx,
 			    sect);
@@ -1118,6 +1120,14 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 	if ((clustalloc == 0) && ((flags & FS_FLAG_META_UNALLOC) == 0))
 	    continue;
 
+
+	/* If it is allocated, but we know it is not allocated to a
+	 * directory then skip it.  NOTE: This will miss unallocated
+	 * entries in slack space of the file...
+	 */
+	if ((clustalloc == 1) && (isset(sect_alloc, sect) == 0))
+	    continue;
+
 	/* The final cluster may not be full */
 	if (lsect - sect + 1 < fatfs->csize)
 	    read_size = lsect - sect + 1;
@@ -1152,7 +1162,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 	    inum = FATFS_SECT_2_INODE(fatfs, sect + i);
 
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"fatfs_inode_walk: Processing sector %" PRIuDADDR
 			" starting at inode %" PRIuINUM "\n", sect + i,
 			inum);
@@ -1222,7 +1232,7 @@ fatfs_inode_walk(FS_INFO * fs, INUM_T start_inum, INUM_T end_inum,
 		fs_inode->flags = myflags;
 
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "fatfs_inode_walk: Directory Entry %" PRIuINUM
 			    " (%u) at sector %" PRIuDADDR "\n", inum, didx,
 			    sect + i);
@@ -1276,6 +1286,11 @@ fatfs_inode_lookup(FS_INFO * fs, INUM_T inum)
 		  " in sector too big for image: %" PRIuDADDR, inum, sect);
 
 
+	if (verbose)
+	    fprintf(stderr,
+		    "fatfs_inode_lookup: reading sector %" PRIuDADDR
+		    " for inode %" PRIuINUM "\n", sect, inum);
+
 	if (fs_read_block(fs, fatfs->dinodes, fatfs->ssize, sect) !=
 	    fatfs->ssize) {
 	    error("fatfs_inode_lookup: Error reading block: %" PRIuDADDR
@@ -1337,7 +1352,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 
 	if (flags & FS_FLAG_FILE_NOABORT) {
 	    if (verbose) {
-		fprintf(logfp,
+		fprintf(stderr,
 			"fatfs_file_walk: Warning: Invalid starting cluster address in Directory Entry (too large): %"
 			PRIuDADDR "", clust);
 	    }
@@ -1355,7 +1370,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	DADDR_T snum = fatfs->firstclustsect - fatfs->firstdatasect;
 
 	if (verbose)
-	    fprintf(logfp, "fatfs_file_walk: Walking Root Directory\n");
+	    fprintf(stderr, "fatfs_file_walk: Walking Root Directory\n");
 
 	for (i = 0; i < snum; i++) {
 	    int myflags = (FS_FLAG_DATA_CONT | FS_FLAG_DATA_ALLOC);
@@ -1383,7 +1398,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fatfs_file_walk: Walking deleted file %" PRIuINUM
 		    " in recovery mode\n", fs_inode->addr);
 
@@ -1401,7 +1416,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	    data_buf_free(data_buf);
 	    if (flags & FS_FLAG_FILE_NOABORT) {
 		if (verbose) {
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "Invalid starting cluster during FAT recovery (too large): %"
 			    PRIuDADDR "", sbase);
 		}
@@ -1417,7 +1432,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	 * recover it */
 	if (is_clustalloc(fatfs, startclust)) {
 	    if (verbose) {
-		fprintf(logfp,
+		fprintf(stderr,
 			"Starting cluster of deleted file is allocated - exiting\n");
 	    }
 	    return;
@@ -1439,7 +1454,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 	     * for the file size */
 	    if (sbase > fs->last_block) {
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "Could not find enough unallocated sectors to recover with - existing\n");
 
 		return;
@@ -1495,7 +1510,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 		    len = (size < fatfs->ssize) ? size : fatfs->ssize;
 
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "fatfs_file_walk: Processing %d bytes of sector %"
 			    PRIuDADDR " for recovery\n", len, (sbase + i));
 
@@ -1511,7 +1526,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
     else {
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fatfs_file_walk: Walking file %" PRIuINUM
 		    " in normal mode\n", fs_inode->addr);
 	/* Cycle through the cluster chain */
@@ -1526,7 +1541,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 		data_buf_free(data_buf);
 		if (flags & FS_FLAG_FILE_NOABORT) {
 		    if (verbose) {
-			fprintf(logfp,
+			fprintf(stderr,
 				"fatfs_file_walk: Invalid sector address in FAT (too large): %"
 				PRIuDADDR "", sbase);
 		    }
@@ -1564,7 +1579,7 @@ fatfs_file_walk(FS_INFO * fs, FS_INODE * fs_inode, uint32_t type,
 		    len = (size < fatfs->ssize) ? size : fatfs->ssize;
 
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "fatfs_file_walk: Processing %d bytes of sector %"
 			    PRIuDADDR "\n", len, (sbase + i));
 
@@ -2052,7 +2067,8 @@ fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 
     fs->file_walk(fs, fs_inode, 0, 0,
 		  (FS_FLAG_FILE_AONLY | FS_FLAG_FILE_SLACK |
-		   FS_FLAG_FILE_NOID), print_addr_act, (void *) &print);
+		   FS_FLAG_FILE_NOID | FS_FLAG_FILE_NOABORT),
+		  print_addr_act, (void *) &print);
 
     if (print.idx != 0)
 	fprintf(hFile, "\n");
@@ -2066,8 +2082,9 @@ fatfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 	print.idx = 0;
 	fs->file_walk(fs, fs_inode, 0, 0,
 		      (FS_FLAG_FILE_AONLY | FS_FLAG_FILE_SLACK |
-		       FS_FLAG_FILE_RECOVER | FS_FLAG_FILE_NOID),
-		      print_addr_act, (void *) &print);
+		       FS_FLAG_FILE_RECOVER | FS_FLAG_FILE_NOID |
+		       FS_FLAG_FILE_NOABORT), print_addr_act,
+		      (void *) &print);
 
 	if (print.istat_seen == 0) {
 	    fprintf(hFile, "File recovery not possible\n");
@@ -2160,7 +2177,10 @@ fatfs_open(IMG_INFO * img_info, unsigned char ftype, uint8_t test)
     fs->dev_bsize = FATFS_DEV_BSIZE;
     fatfs->ssize = getu16(fs, fatsb->ssize);
 
-    if (fatfs->ssize % fs->dev_bsize) {
+    if ((fatfs->ssize % 512) ||
+	((fatfs->ssize != 512) && (fatfs->ssize != 1024) &&
+	 (fatfs->ssize != 2048) && (fatfs->ssize != 4096))) {
+
 	free(fatsb);
 	free(fatfs);
 	if (test)
