@@ -1,18 +1,25 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/10/13 04:15:21 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
 **
 ** TASK
 ** Copyright (c) 2002 @stake Inc.  All rights reserved
+**
+** This software is distributed under the Common Public License 1.0
+**
 */
 
 #ifndef _FATFS_H
 #define _FATFS_H
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 /*
 ** Constants
 */
@@ -28,7 +35,8 @@
 #define FATFS_DEV_BSIZE 512
 #define FATFS_SBOFF		0
 #define FATFS_FS_MAGIC	0xaa55
-#define FATFS_MAXNAMLEN	271	/* 256 + 8.3 name appended stuff */
+#define FATFS_MAXNAMLEN	256
+#define FATFS_MAXNAMLEN_UTF8	1024
 
 /* size of FAT to read into FATFS_INFO each time */
 /* This must be at least 1024 bytes or else fat12 will get messed up */
@@ -87,79 +95,79 @@
 /*
  * Boot Sector Structure for FAT12, FAT16, and FAT32
  */
-typedef struct {
-    uint8_t f1[3];
-    char oemname[8];
-    uint8_t ssize[2];		/* sector size in bytes */
-    uint8_t csize;		/* cluster size in sectors */
-    uint8_t reserved[2];	/* number of reserved sectors for boot sectors */
-    uint8_t numfat;		/* Number of FATs */
-    uint8_t numroot[2];		/* Number of Root dentries */
-    uint8_t sectors16[2];	/* number of sectors in FS */
-    uint8_t f2[1];
-    uint8_t sectperfat16[2];	/* size of FAT */
-    uint8_t f3[4];
-    uint8_t prevsect[4];	/* number of sectors before FS partition */
-    uint8_t sectors32[4];	/* 32-bit value of number of FS sectors */
+    typedef struct {
+	uint8_t f1[3];
+	char oemname[8];
+	uint8_t ssize[2];	/* sector size in bytes */
+	uint8_t csize;		/* cluster size in sectors */
+	uint8_t reserved[2];	/* number of reserved sectors for boot sectors */
+	uint8_t numfat;		/* Number of FATs */
+	uint8_t numroot[2];	/* Number of Root dentries */
+	uint8_t sectors16[2];	/* number of sectors in FS */
+	uint8_t f2[1];
+	uint8_t sectperfat16[2];	/* size of FAT */
+	uint8_t f3[4];
+	uint8_t prevsect[4];	/* number of sectors before FS partition */
+	uint8_t sectors32[4];	/* 32-bit value of number of FS sectors */
 
-    /* The following are different for fat12/fat16 and fat32 */
-    union {
-	struct {
-	    uint8_t f5[3];
-	    uint8_t vol_id[4];
-	    uint8_t vol_lab[11];
-	    uint8_t fs_type[8];
-	    uint8_t f6[448];
-	} f16;
-	struct {
-	    uint8_t sectperfat32[4];
-	    uint8_t ext_flag[2];
-	    uint8_t fs_ver[2];
-	    uint8_t rootclust[4];	/* cluster where root directory is stored */
-	    uint8_t fsinfo[2];	/* FS_INFO Location */
-	    uint8_t bs_backup[2];	/* sector of backup of boot sector */
-	    uint8_t f5[12];
-	    uint8_t drvnum;
-	    uint8_t f6[2];
-	    uint8_t vol_id[4];
-	    uint8_t vol_lab[11];
-	    uint8_t fs_type[8];
-	    uint8_t f7[420];
-	} f32;
-    } a;
+	/* The following are different for fat12/fat16 and fat32 */
+	union {
+	    struct {
+		uint8_t f5[3];
+		uint8_t vol_id[4];
+		uint8_t vol_lab[11];
+		uint8_t fs_type[8];
+		uint8_t f6[448];
+	    } f16;
+	    struct {
+		uint8_t sectperfat32[4];
+		uint8_t ext_flag[2];
+		uint8_t fs_ver[2];
+		uint8_t rootclust[4];	/* cluster where root directory is stored */
+		uint8_t fsinfo[2];	/* FS_INFO Location */
+		uint8_t bs_backup[2];	/* sector of backup of boot sector */
+		uint8_t f5[12];
+		uint8_t drvnum;
+		uint8_t f6[2];
+		uint8_t vol_id[4];
+		uint8_t vol_lab[11];
+		uint8_t fs_type[8];
+		uint8_t f7[420];
+	    } f32;
+	} a;
 
-    uint8_t magic[2];		/* MAGIC for all versions */
+	uint8_t magic[2];	/* MAGIC for all versions */
 
-} fatfs_sb;
+    } fatfs_sb;
 
-typedef struct {
-    uint8_t magic1[4];		/* 41615252 */
-    uint8_t f1[480];
-    uint8_t magic2[4];		/* 61417272 */
-    uint8_t freecnt[4];		/* free clusters 0xfffffffff if unknown */
-    uint8_t nextfree[4];	/* next free cluster */
-    uint8_t f2[12];
-    uint8_t magic3[4];		/* AA550000 */
-} fatfs_fsinfo;
+    typedef struct {
+	uint8_t magic1[4];	/* 41615252 */
+	uint8_t f1[480];
+	uint8_t magic2[4];	/* 61417272 */
+	uint8_t freecnt[4];	/* free clusters 0xfffffffff if unknown */
+	uint8_t nextfree[4];	/* next free cluster */
+	uint8_t f2[12];
+	uint8_t magic3[4];	/* AA550000 */
+    } fatfs_fsinfo;
 
 
 
 /* directory entry short name structure */
-typedef struct {
-    uint8_t name[8];
-    uint8_t ext[3];
-    uint8_t attrib;
-    uint8_t lowercase;
-    uint8_t ctimeten;		/* create times */
-    uint8_t ctime[2];
-    uint8_t cdate[2];
-    uint8_t adate[2];		/* access time */
-    uint8_t highclust[2];
-    uint8_t wtime[2];		/* last write time */
-    uint8_t wdate[2];
-    uint8_t startclust[2];
-    uint8_t size[4];
-} fatfs_dentry;
+    typedef struct {
+	uint8_t name[8];
+	uint8_t ext[3];
+	uint8_t attrib;
+	uint8_t lowercase;
+	uint8_t ctimeten;	/* create times */
+	uint8_t ctime[2];
+	uint8_t cdate[2];
+	uint8_t adate[2];	/* access time */
+	uint8_t highclust[2];
+	uint8_t wtime[2];	/* last write time */
+	uint8_t wdate[2];
+	uint8_t startclust[2];
+	uint8_t size[4];
+    } fatfs_dentry;
 
 
 /* Macro to combine the upper and lower 2-byte parts of the starting
@@ -179,31 +187,17 @@ typedef struct {
  * NOTE: 0x05 is allowed in name[0], and 0x2e (".") is allowed for name[0]
  * and name[1] and 0xe5 is allowed for name[0]
  */
+
 #define FATFS_IS_83_NAME(c)		\
-	(((FATFS_IS_LFN_NAME(c) == 0)	|| \
-	  ((c) == 0x00) || \
-	  ((c) == 0x2b) || \
-	  ((c) == 0x2c) || \
-	  ((c) == 0x2e) || \
-	  ((c) == 0x3a) || \
-	  ((c) == 0x3b) || \
-	  ((c) == 0x3d) || \
-	  ((c) == 0x5b) || \
-	  ((c) == 0x5d) || \
-	  ((c) == 0xff)) == 0)
-
-
-#define FATFS_IS_LFN_NAME(c)	\
-	(((((c) > 0x00) && ((c) < 0x20)) || \
+	((((c) < 0x20) || \
 	  ((c) == 0x22) || \
-	  ((c) == 0x2a) || \
+	  (((c) >= 0x2a) && ((c) <= 0x2c)) || \
+	  ((c) == 0x2e) || \
 	  ((c) == 0x2f) || \
-	  ((c) == 0x3c) || \
-	  ((c) == 0x3e) || \
-	  ((c) == 0x3f) || \
-	  ((c) == 0x5c) || \
-	  ((c) == 0x7c) || \
-	  (((c) >= 0x80) && ((c) < 0xff)))  == 0)
+	  (((c) >= 0x3a) && ((c) <= 0x3f)) || \
+	  (((c) >= 0x5b) && ((c) <= 0x5d)) || \
+	  ((c) == 0x7c)) == 0)
+
 
 
 /* flags for attributes field */
@@ -267,66 +261,66 @@ typedef struct {
  *
  * Contents of this are in UNICODE, not ASCII 
  */
-typedef struct {
-    uint8_t seq;
-    uint8_t part1[10];
-    uint8_t attributes;
-    uint8_t reserved1;
-    uint8_t chksum;
-    uint8_t part2[12];
-    uint8_t reserved2[2];
-    uint8_t part3[4];
-} fatfs_dentry_lfn;
+    typedef struct {
+	uint8_t seq;
+	uint8_t part1[10];
+	uint8_t attributes;
+	uint8_t reserved1;
+	uint8_t chksum;
+	uint8_t part2[12];
+	uint8_t reserved2[2];
+	uint8_t part3[4];
+    } fatfs_dentry_lfn;
 
 /* flags for seq field */
-#define FATFS_LFN_LAST	0x40	/* This bit is set for the first lfn entry */
-#define FATFS_LFN_CNT	0x3f	/* These bits are a mask for the decreasing
-				 * sequence number for the entries */
+#define FATFS_LFN_SEQ_FIRST	0x40	/* This bit is set for the first lfn entry */
+#define FATFS_LFN_SEQ_MASK	0x3f	/* These bits are a mask for the decreasing
+					 * sequence number for the entries */
 
 /* internal FATFS_INFO structure */
-typedef struct {
-    FS_INFO fs_info;		/* super class */
-    DATA_BUF *table;		/* cached section of file allocation table */
+    typedef struct {
+	FS_INFO fs_info;	/* super class */
+	DATA_BUF *table;	/* cached section of file allocation table */
 
-    DATA_BUF *dinodes;		/* sector size buffer of inode list */
-    fatfs_sb *sb;
+	DATA_BUF *dinodes;	/* sector size buffer of inode list */
+	fatfs_sb *sb;
 
-    fatfs_dentry *dep;
+	fatfs_dentry *dep;
 
 
-    /* FIrst sector of FAT */
-    DADDR_T firstfatsect;
+	/* FIrst sector of FAT */
+	DADDR_T firstfatsect;
 
-    /* First sector after FAT  - For FAT12 and FAT16, this is where the
-     * root directory entries are.  For FAT32, this is the the first 
-     * cluster */
-    DADDR_T firstdatasect;
+	/* First sector after FAT  - For FAT12 and FAT16, this is where the
+	 * root directory entries are.  For FAT32, this is the the first 
+	 * cluster */
+	DADDR_T firstdatasect;
 
-    /* The sector number were cluster 2 (the first one) is
-     * for FAT32, it will be the same as firstdatasect, but for FAT12 & 16
-     * it will be the first sector after the Root directory  */
-    DADDR_T firstclustsect;
+	/* The sector number were cluster 2 (the first one) is
+	 * for FAT32, it will be the same as firstdatasect, but for FAT12 & 16
+	 * it will be the first sector after the Root directory  */
+	DADDR_T firstclustsect;
 
-    /* size of data area in clusters, starting at firstdatasect */
-    DADDR_T clustcnt;
+	/* size of data area in clusters, starting at firstdatasect */
+	DADDR_T clustcnt;
 
-    DADDR_T lastclust;
+	DADDR_T lastclust;
 
-    /* sector where the root directory is located */
-    DADDR_T rootsect;
+	/* sector where the root directory is located */
+	DADDR_T rootsect;
 
-    uint32_t dentry_cnt_se;	/* max number of dentries per sector */
-    uint32_t dentry_cnt_cl;	/* max number of dentries per cluster */
+	uint32_t dentry_cnt_se;	/* max number of dentries per sector */
+	uint32_t dentry_cnt_cl;	/* max number of dentries per cluster */
 
-    uint16_t ssize;		/* size of sectors in bytes */
-    uint8_t csize;		/* size of clusters in sectors */
-    //uint16_t      reserved;       /* number of reserved sectors */
-    uint8_t numfat;		/* number of fat tables */
-    uint32_t sectperfat;	/* sectors per fat table */
-    uint16_t numroot;		/* number of 32-byte dentries in root dir */
-    uint32_t mask;		/* the mask to use for the sectors */
+	uint16_t ssize;		/* size of sectors in bytes */
+	uint8_t csize;		/* size of clusters in sectors */
+	//uint16_t      reserved;       /* number of reserved sectors */
+	uint8_t numfat;		/* number of fat tables */
+	uint32_t sectperfat;	/* sectors per fat table */
+	uint16_t numroot;	/* number of 32-byte dentries in root dir */
+	uint32_t mask;		/* the mask to use for the sectors */
 
-} FATFS_INFO;
+    } FATFS_INFO;
 
 
 /*
@@ -336,12 +330,16 @@ typedef struct {
 #define is_clustalloc(fs, c) \
     (getFAT((fs), (c)) != FATFS_UNALLOC)
 
-extern uint8_t is_sectalloc(FATFS_INFO *, DADDR_T);
+    extern uint8_t is_sectalloc(FATFS_INFO *, DADDR_T);
 
-extern void fatfs_dent_walk(FS_INFO *, INUM_T, int, FS_DENT_WALK_FN,
-			    void *);
-extern uint8_t fatfs_isdentry(FATFS_INFO *, fatfs_dentry *);
-extern void fatfs_make_root(FATFS_INFO *, FS_INODE *);
-extern void fatfs_dinode_copy(FATFS_INFO *, FS_INODE *, fatfs_dentry *,
-			      DADDR_T, INUM_T);
+    extern void fatfs_dent_walk(FS_INFO *, INUM_T, int, FS_DENT_WALK_FN,
+				void *);
+    extern uint8_t fatfs_isdentry(FATFS_INFO *, fatfs_dentry *);
+    extern void fatfs_make_root(FATFS_INFO *, FS_INODE *);
+    extern void fatfs_dinode_copy(FATFS_INFO *, FS_INODE *, fatfs_dentry *,
+				  DADDR_T, INUM_T);
+
+#ifdef __cplusplus
+}
+#endif
 #endif
