@@ -2,7 +2,7 @@
 ** fatfs_dent
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/10/13 04:15:21 $
 **
 ** Human interface Layer support for the FAT file system
 **
@@ -12,10 +12,16 @@
 ** TASK
 ** Copyright (c) 2002 Brian Carrier, @stake Inc.  All rights reserved
 **
+**
+** This software is distributed under the Common Public License 1.0
+**
+** Unicode added with support from I.D.E.A.L. Technology Corp (Aug '05)
+**
 */
 
 #include "fs_tools.h"
 #include "fatfs.h"
+#include "fs_unicode.h"
 
 /*
  * DESIGN NOTES
@@ -42,8 +48,8 @@
 /* Special data structure allocated for each directory to hold the long
  * file name entries until all entries have been found */
 typedef struct {
-    char name[FATFS_MAXNAMLEN];	/* buffer for lfn - in reverse order */
-    uint16_t len;		/* current length  of name */
+    uint8_t name[FATFS_MAXNAMLEN_UTF8];	/* buffer for lfn - in reverse order */
+    uint16_t start;		/* current start of name */
     uint8_t chk;		/* current checksum */
     uint8_t seq;		/* seq of first entry in lfn */
 } FATFS_LFN;
@@ -88,182 +94,6 @@ static void fatfs_dent_walk_lcl(FS_INFO *, FATFS_DINFO *, INUM_T, int,
 				FS_DENT_WALK_FN, void *);
 
 
-/*
- * Copy the contents of the FAT specific directory entry into the generic
- * one.
- *
- * This gets interesting with the way that FAT handles long file names.
- * LFN are handled by proceeding the original 8.3 entry with special
- * structures that handle 13 UNICODE values.  These have a special 
- * attribute set.  The LFN structures are in reverse order and end with
- * an 8.3 entry with the short version of the name.
- *
- * We handle this by copying the LFN values into the FATFS_LFN structure
- * and then when we get the 8.3 entry the long name is copied in.  Therefore,
- * FATFS_LFN keeps state between calls to this function.
- *
- * Ideally, we should print out the partial lfn when we find one with a
- * new checksum, but that does not work because this is supposed to return
- * only one entry and that case may cause two entries to be returned.
- */
-static void
-fatfs_dent_copy(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
-		FATFS_LFN * lfninfo, char *fatfs_dent, FS_DENT * fs_dent,
-		INUM_T inum, DADDR_T sect)
-{
-    int i;
-    fatfs_dentry *dir = (fatfs_dentry *) fatfs_dent;
-
-    fs_dent->inode = inum;
-
-    /* Name */
-    if ((dir->attrib & FATFS_ATTR_LFN) == FATFS_ATTR_LFN) {
-	fatfs_dentry_lfn *dirl = (fatfs_dentry_lfn *) fatfs_dent;
-
-	/* Store the name in dinfo until we get the 8.3 name */
-
-	/* Is this a new sequence?  The checksum is the same for all entries
-	 * in the same sequence 
-	 */
-
-	if (dirl->chksum != lfninfo->chk) {
-	    lfninfo->seq = dirl->seq;
-	    lfninfo->chk = dirl->chksum;
-	    lfninfo->len = 0;
-	}
-
-	/* we are only going to support ASCII - not full UNICODE */
-	for (i = 2; i >= 0; i -= 2) {
-	    if ((dirl->part3[i] != 0) && (dirl->part3[i] != 0xff)) {
-		if (lfninfo->len < FATFS_MAXNAMLEN)
-		    lfninfo->name[lfninfo->len++] = dirl->part3[i];
-	    }
-	}
-	for (i = 10; i >= 0; i -= 2) {
-	    if ((dirl->part2[i] != 0) && (dirl->part2[i] != 0xff)) {
-		if (lfninfo->len < FATFS_MAXNAMLEN)
-		    lfninfo->name[lfninfo->len++] = dirl->part2[i];
-	    }
-	}
-	for (i = 8; i >= 0; i -= 2) {
-	    if ((dirl->part1[i] != 0) && (dirl->part1[i] != 0xff)) {
-		if (lfninfo->len < FATFS_MAXNAMLEN)
-		    lfninfo->name[lfninfo->len++] = dirl->part1[i];
-	    }
-	}
-    }
-    /* Special case for volume label, where name does not have an
-     * extension and we add a note at the end that it is a label */
-    else if ((dir->attrib & FATFS_ATTR_VOLUME) == FATFS_ATTR_VOLUME) {
-	fs_dent->namlen = 0;
-	for (i = 0; i < 8; i++) {
-	    if ((dir->name[i] != 0) && (dir->name[i] != 0xff)) {
-		fs_dent->name[fs_dent->namlen++] = dir->name[i];
-	    }
-	}
-	for (i = 0; i < 3; i++) {
-	    if ((dir->ext[i] != 0) && (dir->ext[i] != 0xff)) {
-		fs_dent->name[fs_dent->namlen++] = dir->ext[i];
-	    }
-	}
-
-	fs_dent->name[fs_dent->namlen] = '\0';
-	/* Append a string to show it is a label */
-	if (fs_dent->namlen + 22 < FATFS_MAXNAMLEN) {
-	    char *volstr = " (Volume Label Entry)";
-	    strncat(fs_dent->name, volstr,
-		    FATFS_MAXNAMLEN - fs_dent->namlen);
-	    fs_dent->namlen += strlen(volstr);
-	}
-    }
-
-    /* we have a short (8.3) entry 
-     * we may have the long name version already stored in the FATFS_INFO
-     */
-    else {
-
-	fs_dent->namlen = 0;
-
-	/* if we have the lfn, copy it in.  Remember it is backwards */
-	/* @@@ We could check the checksum, but how would we report it */
-	if (lfninfo->len != 0) {
-	    for (i = 0; i < lfninfo->len; i++)
-		fs_dent->name[fs_dent->namlen++] =
-		    lfninfo->name[lfninfo->len - 1 - i];
-
-	    /* we will have the short name appended as (xxxxxxx.xxx) */
-	    if (fs_dent->namlen + 2 < FATFS_MAXNAMLEN) {
-		fs_dent->name[fs_dent->namlen++] = ' ';
-		fs_dent->name[fs_dent->namlen++] = '(';
-	    }
-
-	}
-
-	if (fs_dent->namlen + 12 < FATFS_MAXNAMLEN) {
-	    /* copy in the short name, skipping spaces and putting in the . */
-	    for (i = 0; i < 8; i++) {
-		if ((dir->name[i] != 0) && (dir->name[i] != 0xff) &&
-		    (dir->name[i] != 0x20)) {
-
-		    if ((i == 0) && (dir->name[0] == FATFS_SLOT_DELETED))
-			fs_dent->name[fs_dent->namlen++] = '_';
-		    else if ((dir->lowercase & FATFS_CASE_LOWER_BASE) &&
-			     (dir->name[i] >= 'A')
-			     && (dir->name[i] <= 'Z'))
-			fs_dent->name[fs_dent->namlen++] =
-			    dir->name[i] + 32;
-		    else
-			fs_dent->name[fs_dent->namlen++] = dir->name[i];
-		}
-	    }
-
-	    for (i = 0; i < 3; i++) {
-		if ((dir->ext[i] != 0) && (dir->ext[i] != 0xff) &&
-		    (dir->ext[i] != 0x20)) {
-		    if (i == 0)
-			fs_dent->name[fs_dent->namlen++] = '.';
-		    if ((dir->lowercase & FATFS_CASE_LOWER_EXT) &&
-			(dir->ext[i] >= 'A') && (dir->ext[i] <= 'Z'))
-			fs_dent->name[fs_dent->namlen++] =
-			    dir->ext[i] + 32;
-		    else
-			fs_dent->name[fs_dent->namlen++] = dir->ext[i];
-		}
-	    }
-	    fs_dent->name[fs_dent->namlen] = '\0';
-	}
-
-	/* If we put the LFN and the short in () then add ) */
-	if (lfninfo->len != 0) {
-	    if (fs_dent->namlen + 1 < FATFS_MAXNAMLEN)
-		fs_dent->name[fs_dent->namlen++] = ')';
-	    fs_dent->name[fs_dent->namlen] = '\0';
-
-	    /* reset the name */
-	    lfninfo->len = 0;
-	}
-    }
-
-
-    /* append the path data */
-    fs_dent->path = dinfo->dirs;
-    fs_dent->pathdepth = dinfo->depth;
-
-
-    /* file type: FAT only knows DIR and FILE */
-    if ((dir->attrib & FATFS_ATTR_DIRECTORY) == FATFS_ATTR_DIRECTORY)
-	fs_dent->ent_type = FS_DENT_DIR;
-    else
-	fs_dent->ent_type = FS_DENT_REG;
-
-    /* Get inode */
-    if (inum)
-	fatfs_dinode_copy(fatfs, fs_dent->fsi, dir, sect, inum);
-
-    return;
-}
-
-
 /**************************************************************************
  *
  * find_parent
@@ -273,8 +103,6 @@ fatfs_dent_copy(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 /*
  * this is the call back for the dent walk when we need to find the 
  * parent directory
- *
- * dinfo->save_state should be 0 when this is running
  */
 static uint8_t
 find_parent_act(FS_INFO * fs, FS_DENT * fsd, int flags, void *ptr)
@@ -309,7 +137,7 @@ find_parent(FATFS_INFO * fatfs, FS_DENT * fs_dent)
     dinfo.find_clust = fs_dent->fsi->direct_addr[0];
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_find_parent: Looking for directory in cluster %"
 		PRIuDADDR "\n", dinfo.find_clust);
 
@@ -342,7 +170,7 @@ find_parent(FATFS_INFO * fatfs, FS_DENT * fs_dent)
 
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_find_parent: Directory %" PRIuINUM
 		" found for cluster %" PRIuDADDR "\n", dinfo.find_inode,
 		dinfo.find_clust);
@@ -367,7 +195,8 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		     DADDR_T * addrs, int flags,
 		     FS_DENT_WALK_FN action, void *ptr)
 {
-    unsigned int idx, i;
+    unsigned int idx, sidx;
+    int a, b;
     INUM_T inode, ibase;
     fatfs_dentry *dep;
     FS_INFO *fs = (FS_INFO *) & fatfs->fs_info;
@@ -380,48 +209,207 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 
     dep = (fatfs_dentry *) buf;
 
-
-    fs_dent = fs_dent_alloc(FATFS_MAXNAMLEN);
+    fs_dent = fs_dent_alloc(FATFS_MAXNAMLEN_UTF8, 32);
     fs_dent->fsi = fs_inode_alloc(FATFS_NDADDR, FATFS_NIADDR);
+
     memset(&lfninfo, 0, sizeof(FATFS_LFN));
+    lfninfo.start = FATFS_MAXNAMLEN_UTF8 - 1;
 
-
-    for (i = 0; i < (unsigned int) (len / 512); i++) {
+    for (sidx = 0; sidx < (unsigned int) (len / 512); sidx++) {
 
 	/* Get the base inode for this sector */
-	ibase = FATFS_SECT_2_INODE(fatfs, addrs[i]);
+	ibase = FATFS_SECT_2_INODE(fatfs, addrs[sidx]);
 	if (ibase > fs->last_inum)
 	    error("parse error: inode address is too large");
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fatfs_dent_parse_buf: Parsing sector %" PRIuDADDR
-		    "\n", addrs[i]);
+		    "\n", addrs[sidx]);
 
-
-	sectalloc = is_sectalloc(fatfs, addrs[i]);
+	sectalloc = is_sectalloc(fatfs, addrs[sidx]);
 
 	/* cycle through the directory entries */
 	for (idx = 0; idx < fatfs->dentry_cnt_se; idx++, dep++) {
-
+	    fatfs_dentry *dir;
 	    int myflags = 0;
 
 	    /* is it a valid dentry? */
 	    if (0 == fatfs_isdentry(fatfs, dep))
 		continue;
 
+	    /* Copy the directory entry into the FS_DENT structure */
+	    dir = (fatfs_dentry *) dep;
+
 	    inode = ibase + idx;
 
-	    /* Copy the entry
-	     * if this is LFN, then the name will be copied into lfninfo */
-	    fatfs_dent_copy(fatfs, dinfo, &lfninfo, (char *) dep, fs_dent,
-			    inode, addrs[i]);
+	    /* Take care of the name */
+	    if ((dir->attrib & FATFS_ATTR_LFN) == FATFS_ATTR_LFN) {
+		fatfs_dentry_lfn *dirl = (fatfs_dentry_lfn *) dir;
+
+		/* Store the name in dinfo until we get the 8.3 name */
+
+		/* Is this a new sequence?  The checksum is the same for all entries
+		 * in the same sequence 
+		 */
+		if (((dirl->seq & FATFS_LFN_SEQ_FIRST)
+		     && (dirl->seq != FATFS_SLOT_DELETED))
+		    || (dirl->chksum != lfninfo.chk)) {
+		    // @@@ Do a partial output here
 
 
-	    /* If it is a long file name, then keep on going until the
-	     * final small name is reached */
-	    if ((dep->attrib & FATFS_ATTR_LFN) == FATFS_ATTR_LFN)
+		    lfninfo.seq = dirl->seq & FATFS_LFN_SEQ_MASK;
+		    lfninfo.chk = dirl->chksum;
+		    lfninfo.start = FATFS_MAXNAMLEN_UTF8 - 1;
+		}
+		else if (dirl->seq != lfninfo.seq - 1) {
+		    // @@@ Check the sequence number - the checksum is correct though...
+
+		}
+
+		/* Copy the UTF16 values starting at end of buffer */
+		for (a = 3; a >= 0; a--) {
+		    if ((lfninfo.start > 0))
+			lfninfo.name[lfninfo.start--] = dirl->part3[a];
+		}
+		for (a = 11; a >= 0; a--) {
+		    if ((lfninfo.start > 0))
+			lfninfo.name[lfninfo.start--] = dirl->part2[a];
+		}
+		for (a = 9; a >= 0; a--) {
+		    if ((lfninfo.start > 0))
+			lfninfo.name[lfninfo.start--] = dirl->part1[a];
+		}
+
+		// Skip ahead until we get a new sequence num or the 8.3 name
 		continue;
+	    }
+	    /* Special case for volume label: name does not have an
+	     * extension and we add a note at the end that it is a label */
+	    else if ((dir->attrib & FATFS_ATTR_VOLUME) ==
+		     FATFS_ATTR_VOLUME) {
+		a = 0;
+
+		for (b = 0; b < 8; b++) {
+		    if ((dir->name[b] != 0) && (dir->name[b] != 0xff)) {
+			fs_dent->name[a++] = dir->name[b];
+		    }
+		}
+		for (b = 0; b < 3; b++) {
+		    if ((dir->ext[b] != 0) && (dir->ext[b] != 0xff)) {
+			fs_dent->name[a++] = dir->ext[b];
+		    }
+		}
+
+		fs_dent->name[a] = '\0';
+		/* Append a string to show it is a label */
+		if (a + 22 < FATFS_MAXNAMLEN_UTF8) {
+		    char *volstr = " (Volume Label Entry)";
+		    strncat(fs_dent->name, volstr,
+			    FATFS_MAXNAMLEN_UTF8 - a);
+		}
+	    }
+
+	    /* A short (8.3) entry */
+	    else {
+		char *name_ptr;	// The dest location for the short name
+
+		/* if we have a lfn, copy it in */
+		if (lfninfo.start != FATFS_MAXNAMLEN_UTF8 - 1) {
+		    int retVal;
+
+		    /* @@@ Check the checksum */
+
+
+
+		    /* Convert the UTF16 to UTF8 */
+		    UTF16 *name16 =
+			(UTF16 *) ((uintptr_t) & lfninfo.
+				   name[lfninfo.start + 1]);
+		    UTF8 *name8 = (UTF8 *) fs_dent->name;
+
+		    retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+					    (UTF16 *) & lfninfo.
+					    name[FATFS_MAXNAMLEN_UTF8],
+					    &name8,
+					    (UTF8 *) ((uintptr_t) name8 +
+						      FATFS_MAXNAMLEN_UTF8),
+					    lenientConversion);
+
+		    if (retVal != conversionOK) {
+			error("Error converting FAT LFN to UTF8: %d",
+			      retVal);
+		    }
+
+		    /* Make sure it is NULL Terminated */
+		    if ((uintptr_t) name8 >
+			(uintptr_t) fs_dent->name + FATFS_MAXNAMLEN_UTF8)
+			fs_dent->name[FATFS_MAXNAMLEN_UTF8 - 1] = '\0';
+		    else
+			*name8 = '\0';
+
+		    lfninfo.start = FATFS_MAXNAMLEN_UTF8 - 1;
+		    name_ptr = fs_dent->shrt_name;	// put 8.3 into shrt_name
+		}
+		else {
+		    fs_dent->shrt_name[0] = '\0';
+		    name_ptr = fs_dent->name;	// put 8.3 into normal location
+		}
+
+
+		/* copy in the short name, skipping spaces and putting in the . */
+		a = 0;
+		for (b = 0; b < 8; b++) {
+		    if ((dir->name[b] != 0) && (dir->name[b] != 0xff) &&
+			(dir->name[b] != 0x20)) {
+
+			if ((b == 0)
+			    && (dir->name[0] == FATFS_SLOT_DELETED)) {
+			    name_ptr[a++] = '_';
+			}
+			else if ((dir->lowercase & FATFS_CASE_LOWER_BASE)
+				 && (dir->name[b] >= 'A')
+				 && (dir->name[b] <= 'Z')) {
+			    name_ptr[a++] = dir->name[b] + 32;
+			}
+			else {
+			    name_ptr[a++] = dir->name[b];
+			}
+		    }
+		}
+
+		for (b = 0; b < 3; b++) {
+		    if ((dir->ext[b] != 0) && (dir->ext[b] != 0xff) &&
+			(dir->ext[b] != 0x20)) {
+			if (b == 0)
+			    name_ptr[a++] = '.';
+			if ((dir->lowercase & FATFS_CASE_LOWER_EXT) &&
+			    (dir->ext[b] >= 'A') && (dir->ext[b] <= 'Z'))
+			    name_ptr[a++] = dir->ext[b] + 32;
+			else
+			    name_ptr[a++] = dir->ext[b];
+		    }
+		}
+		name_ptr[a] = '\0';
+	    }
+
+	    /* add the path data */
+	    fs_dent->path = dinfo->dirs;
+	    fs_dent->pathdepth = dinfo->depth;
+
+
+	    /* file type: FAT only knows DIR and FILE */
+	    if ((dir->attrib & FATFS_ATTR_DIRECTORY) ==
+		FATFS_ATTR_DIRECTORY)
+		fs_dent->ent_type = FS_DENT_DIR;
+	    else
+		fs_dent->ent_type = FS_DENT_REG;
+
+	    /* Get inode */
+	    fs_dent->inode = inode;
+	    fatfs_dinode_copy(fatfs, fs_dent->fsi, dir, addrs[sidx],
+			      inode);
+
 
 	    /* Handle the . and .. entries specially
 	     * The current inode 'address' they have is for the current
@@ -437,8 +425,6 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		/* dinfo->pardir_inode is not always set, so we may have to search */
 		else if (dep->name[1] == '.') {
 
-		    /* dinfo->save_state is set to 0 when we are already looking
-		     * for a parent by its cluster */
 		    if ((!dinfo->pardir_inode) && (!dinfo->find_clust))
 			dinfo->pardir_inode = find_parent(fatfs, fs_dent);
 
@@ -481,29 +467,11 @@ fatfs_dent_parse_buf(FATFS_INFO * fatfs, FATFS_DINFO * dinfo,
 		uint8_t back_recdel = 0;
 
 
-		/* we are going to append only the short name */
+		/* append our name */
 		if (dinfo->depth < MAX_DEPTH) {
-		    char tmpname[13];
-
-		    /* Extract out the short name */
-		    if (strrchr(fs_dent->name, '(')) {
-			int i;
-			char *ptr = strrchr(fs_dent->name, '(');
-			ptr++;
-
-			for (i = 0; i < 12 && ptr[i] != ')'; i++)
-			    tmpname[i] = ptr[i];
-
-			tmpname[i] = '\0';
-
-		    }
-		    else {
-			strncpy(tmpname, fs_dent->name, 13);
-		    }
-
 		    dinfo->didx[dinfo->depth] =
 			&dinfo->dirs[strlen(dinfo->dirs)];
-		    strncpy(dinfo->didx[dinfo->depth], tmpname,
+		    strncpy(dinfo->didx[dinfo->depth], fs_dent->name,
 			    DIR_STRSZ - strlen(dinfo->dirs));
 		    strncat(dinfo->dirs, "/", DIR_STRSZ);
 		}
@@ -593,7 +561,7 @@ fatfs_dent_action(FS_INFO * fs, DADDR_T addr, char *buf,
      * if we are at the last entry, then realloc more */
     if (load->addridx == load->addrsize) {
 	if (verbose)
-	    fprintf(logfp, "fatfs_dent_action: realloc curaddrbuf");
+	    fprintf(stderr, "fatfs_dent_action: realloc curaddrbuf");
 
 	load->addrsize += 512;
 	load->curaddrbuf = (DADDR_T *) myrealloc((char *) load->curaddrbuf,
@@ -653,7 +621,7 @@ fatfs_dent_walk_lcl(FS_INFO * fs, FATFS_DINFO * dinfo, INUM_T inode,
     len = roundup(size, 512);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fatfs_dent_walk: Processing directory %" PRIuINUM "\n",
 		inode);
 
@@ -676,36 +644,25 @@ fatfs_dent_walk_lcl(FS_INFO * fs, FATFS_DINFO * dinfo, INUM_T inode,
     load.curaddrbuf = addrbuf;
 
     /* save the directory contents into dirbuf */
-    if (dinfo->recdel == 0) {
-	fs->file_walk(fs, fs_inode, 0, 0,
-		      FS_FLAG_FILE_SLACK | FS_FLAG_FILE_NOID,
-		      fatfs_dent_action, (void *) &load);
+    fs->file_walk(fs, fs_inode, 0, 0,
+		  FS_FLAG_FILE_SLACK | FS_FLAG_FILE_RECOVER |
+		  FS_FLAG_FILE_NOID | FS_FLAG_FILE_NOABORT,
+		  fatfs_dent_action, (void *) &load);
 
-	if (load.dirleft > 0) {
-	    error
-		("fatfs_dent_walk: Entire directory was not loaded (%Zd left)",
-		 load.dirleft);
-	}
-    }
-    else {
-	fs->file_walk(fs, fs_inode, 0, 0,
-		      FS_FLAG_FILE_SLACK | FS_FLAG_FILE_RECOVER |
-		      FS_FLAG_FILE_NOID, fatfs_dent_action,
-		      (void *) &load);
 
-	/* We did not copy the entire directory, but it was a deleted dir. 
-	 * During recovery of a deleted file, the FAT code will only
-	 * return content if it can recover the entire file
-	 */
-	if (load.dirleft > 0) {
+    /* We did not copy the entire directory, which occurs if an error occured */
+    if (load.dirleft > 0) {
 
-	    /* Free the local buffers */
-	    free(load.curaddrbuf);
-	    free(load.curdirptr);
-	    fs_inode_free(fs_inode);
+	/* Free the local buffers */
+	free(load.curaddrbuf);
+	free(load.curdirptr);
+	fs_inode_free(fs_inode);
 
-	    return;
-	}
+	if (dinfo->depth == 0)
+	    error("Error reading directory contents: %" PRIuINUM "\n",
+		  inode);
+
+	return;
     }
 
     /* Reset the local pointer because we could have done a realloc */
