@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/09/02 19:53:27 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -816,7 +816,7 @@ ffs_file_walk_direct(FS_INFO * fs, DATA_BUF * buf,
     if (addr > fs->last_block) {
 	if (flags & FS_FLAG_FILE_NOABORT) {
 	    if (verbose) {
-		fprintf(logfp,
+		fprintf(stderr,
 			"Invalid direct block address (too large): %"
 			PRIuDADDR "", addr);
 	    }
@@ -883,13 +883,13 @@ ffs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
     unsigned int n;
 
     if (verbose)
-	fprintf(logfp, "%s: level %d block %" PRIuDADDR "\n", myname,
+	fprintf(stderr, "%s: level %d block %" PRIuDADDR "\n", myname,
 		level, addr);
 
     if (addr > fs->last_block) {
 	if (flags & FS_FLAG_FILE_NOABORT) {
 	    if (verbose) {
-		fprintf(logfp,
+		fprintf(stderr,
 			"Invalid indirect block address (too large): %"
 			PRIuDADDR "", addr);
 	    }
@@ -939,7 +939,7 @@ ffs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	    if (getu32(fs, (uint8_t *) & iaddr[n]) > fs->last_block) {
 		if (flags & FS_FLAG_FILE_NOABORT) {
 		    if (verbose) {
-			fprintf(logfp,
+			fprintf(stderr,
 				"Invalid address in indirect list (too large): %"
 				PRIu32 "", getu32(fs,
 						  (uint8_t *) & iaddr[n]));
@@ -986,7 +986,7 @@ ffs_file_walk_indir(FS_INFO * fs, DATA_BUF * buf[], OFF_T length,
 	    if (getu64(fs, (uint8_t *) & iaddr[n]) > fs->last_block) {
 		if (flags & FS_FLAG_FILE_NOABORT) {
 		    if (verbose) {
-			fprintf(logfp,
+			fprintf(stderr,
 				"Invalid address in indirect list (too large): %"
 				PRIuDADDR "", getu64(fs,
 						     (uint8_t *) &
@@ -1051,7 +1051,7 @@ ffs_file_walk(FS_INFO * fs, FS_INODE * inode, uint32_t type, uint16_t id,
     int level;
 
     if (verbose)
-	fprintf(logfp, "ffs_file_walk: Processing file %" PRIuINUM "\n",
+	fprintf(stderr, "ffs_file_walk: Processing file %" PRIuINUM "\n",
 		inode->addr);
 
     /*
@@ -1139,7 +1139,8 @@ ffs_fsstat(FS_INFO * fs, FILE * hFile)
     if ((fs->ftype == FFS_1) || (fs->ftype == FFS_1B)) {
 	fprintf(hFile, "File System Type: UFS 1\n");
 	tmptime = getu32(fs, sb1->wtime);
-	fprintf(hFile, "Last Written: %s", asctime(localtime(&tmptime)));
+	fprintf(hFile, "Last Written: %s",
+		(tmptime > 0) ? asctime(localtime(&tmptime)) : "empty");
 	fprintf(hFile, "Last Mount Point: %s\n", sb1->last_mnt);
 
 	flags = sb1->fs_flags;
@@ -1147,7 +1148,8 @@ ffs_fsstat(FS_INFO * fs, FILE * hFile)
     else {
 	fprintf(hFile, "File System Type: UFS 2\n");
 	tmptime = getu32(fs, sb2->wtime);
-	fprintf(hFile, "Last Written: %s", asctime(localtime(&tmptime)));
+	fprintf(hFile, "Last Written: %s",
+		(tmptime > 0) ? asctime(localtime(&tmptime)) : "empty");
 	fprintf(hFile, "Last Mount Point: %s\n", sb2->last_mnt);
 	fprintf(hFile, "Volume Name: %s\n", sb2->volname);
 	fprintf(hFile, "System UID: %" PRIu64 "\n",
@@ -1287,7 +1289,8 @@ ffs_fsstat(FS_INFO * fs, FILE * hFile)
 		tmptime = (uint32_t) getu64(fs, cgd2->wtime);
 	    }
 	    fprintf(hFile, "  Last Written: %s",
-		    asctime(localtime(&tmptime)));
+		    (tmptime >
+		     0) ? asctime(localtime(&tmptime)) : "empty");
 	}
 
 	fprintf(hFile, "  Inode Range: %" PRIu32 " - %" PRIu32 "\n",
@@ -1617,7 +1620,8 @@ ffs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
 
     fs->file_walk(fs, fs_inode, 0, 0,
 		  FS_FLAG_FILE_AONLY | FS_FLAG_FILE_META |
-		  FS_FLAG_FILE_NOID, print_addr_act, (void *) &print);
+		  FS_FLAG_FILE_NOID | FS_FLAG_FILE_NOABORT,
+		  print_addr_act, (void *) &print);
 
     if (print.idx != 0)
 	fprintf(hFile, "\n");
@@ -1858,7 +1862,7 @@ ffs_open(IMG_INFO * img_info, unsigned char ftype, uint8_t test)
      * Print some stats.
      */
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"inodes %" PRIuINUM " root ino %" PRIuINUM " cyl groups %"
 		PRId32 " blocks %" PRIuDADDR "\n", fs->inum_count,
 		fs->root_inum, ffs->groups_count, fs->block_count);
