@@ -2,7 +2,7 @@
 ** ffs_dent
 ** The  Sleuth Kit 
 **
-** $Date: 2005/06/14 04:10:01 $
+** $Date: 2005/10/13 04:15:21 $
 **
 ** Human Interface Layer Support for a FFS image 
 **
@@ -12,41 +12,11 @@
 ** TASK
 ** Copyright (c) 2002 Brian Carrier, @stake Inc.  All rights reserved
 **
-**
 ** TCTUTILs
-** Brian Carrier [carrier@cerias.purdue.edu]
 ** Copyright (c) 2001 Brian Carrier.  All rights reserved
 **
-** Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are
-** met:
 **
-** 1. Redistributions of source code must retain the above copyright notice,
-**    this list of conditions and the following disclaimer.
-** 2. Redistributions in binary form must reproduce the above copyright
-**    notice, this list of conditions and the following disclaimer in the
-**    documentation and/or other materials provided with the distribution.
-** 3. The name of the author may not be used to endorse or promote
-**    products derived from this software without specific prior written
-**    permission.     
-**
-**
-** THIS SOFTWARE IS NOT AFFILIATED WITH PURDUE UNIVERSITY OR THE CENTER FOR
-** EDUCATION IN INFORMATION ASSURANCE AND SECURITY (CERIAS) AND THEY BEAR
-** NO RESPONSIBILITY FOR ITS USE OR MISUSE.
-**
-**
-** THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
-** WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-** MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
-**
-** IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
-** INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-** (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR
-** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-** OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-** ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+** This software is distributed under the Common Public License 1.0
 **
 */
 
@@ -84,7 +54,6 @@ ffs_dent_copy(FFS_INFO * ffs, FFS_DINFO * dinfo, char *ffs_dent,
 	      FS_DENT * fs_dent)
 {
     FS_INFO *fs = &(ffs->fs_info);
-    int i;
 
     /* this one has the type field */
     if ((fs->ftype == FFS_1) || (fs->ftype == FFS_2)) {
@@ -92,14 +61,11 @@ ffs_dent_copy(FFS_INFO * ffs, FFS_DINFO * dinfo, char *ffs_dent,
 
 	fs_dent->inode = getu32(fs, dir->d_ino);
 
-	/* NOTE: d_namlen is 8 bits in this structure, not 16 */
-	fs_dent->namlen = dir->d_namlen;
-
-	if (fs_dent->maxnamlen != FFS_MAXNAMLEN)
+	if (fs_dent->name_max != FFS_MAXNAMLEN)
 	    fs_dent_realloc(fs_dent, FFS_MAXNAMLEN);
 
 	/* ffs null terminates so we can strncpy */
-	strncpy(fs_dent->name, dir->d_name, fs_dent->maxnamlen);
+	strncpy(fs_dent->name, dir->d_name, fs_dent->name_max);
 
 	/* generic types are same as FFS */
 	fs_dent->ent_type = dir->d_type;
@@ -109,13 +75,12 @@ ffs_dent_copy(FFS_INFO * ffs, FFS_DINFO * dinfo, char *ffs_dent,
 	ffs_dentry2 *dir = (ffs_dentry2 *) ffs_dent;
 
 	fs_dent->inode = getu32(fs, dir->d_ino);
-	fs_dent->namlen = getu16(fs, dir->d_namlen);
 
-	if (fs_dent->maxnamlen != FFS_MAXNAMLEN)
+	if (fs_dent->name_max != FFS_MAXNAMLEN)
 	    fs_dent_realloc(fs_dent, FFS_MAXNAMLEN);
 
 	/* ffs null terminates so we can strncpy */
-	strncpy(fs_dent->name, dir->d_name, fs_dent->maxnamlen);
+	strncpy(fs_dent->name, dir->d_name, fs_dent->name_max);
 
 	fs_dent->ent_type = FS_DENT_UNDEF;
     }
@@ -127,34 +92,6 @@ ffs_dent_copy(FFS_INFO * ffs, FFS_DINFO * dinfo, char *ffs_dent,
     fs_dent->path = dinfo->dirs;
     fs_dent->pathdepth = dinfo->depth;
 
-    /* replace non-printable with ^. */
-    for (i = 0; i < fs_dent->namlen; i++) {
-
-	if (isprint((int) fs_dent->name[i]) == 0) {
-
-	    /* Our buffer is FFS_MAXNAMLEN + 1 */
-	    if (fs_dent->namlen < FFS_MAXNAMLEN) {
-		int a;
-		fs_dent->name[fs_dent->namlen + 2] = '\0';
-		for (a = fs_dent->namlen; a > i; a--) {
-		    fs_dent->name[a + 1] = fs_dent->name[a];
-		}
-		if (isprint((int) (fs_dent->name[i] & 0x7f))) {
-		    fs_dent->name[i + 1] = fs_dent->name[i] & 0x7f;
-		}
-		else {
-		    fs_dent->name[i + 1] = '.';
-		}
-		fs_dent->name[i] = '^';
-		fs_dent->namlen++;
-	    }
-	    else {
-		fs_dent->name[i] = '.';
-	    }
-	}
-    }
-
-
     if ((fs != NULL) && (fs_dent->inode)) {
 	/* Get inode */
 	if (fs_dent->fsi)
@@ -189,7 +126,7 @@ ffs_dent_parse_block(FFS_INFO * ffs, FFS_DINFO * dinfo, char *buf,
     char *dirPtr;
     FS_DENT *fs_dent;
 
-    fs_dent = fs_dent_alloc(FFS_MAXNAMLEN + 1);
+    fs_dent = fs_dent_alloc(FFS_MAXNAMLEN + 1, 0);
 
     /* update each time by the actual length instead of the
      ** recorded length so we can view the deleted entries 
@@ -227,8 +164,7 @@ ffs_dent_parse_block(FFS_INFO * ffs, FFS_DINFO * dinfo, char *buf,
 	    (inode < 0) ||
 	    (namelen > FFS_MAXNAMLEN) ||
 	    (namelen <= 0) ||
-	    (reclen < minreclen) ||
-	    (reclen % 4) || (reclen > FFS_DIRBLKSIZ)) {
+	    (reclen < minreclen) || (reclen % 4) || (idx + reclen > len)) {
 
 	    /* we don't have a valid entry, so skip ahead 4 */
 	    minreclen = 4;
@@ -344,7 +280,7 @@ ffs_dent_walk_lcl(FS_INFO * fs, FFS_DINFO * dinfo, INUM_T inode, int flags,
 	error("invalid inode value: %" PRIuINUM "\n", inode);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"fffs_dent_walk: Processing directory %" PRIuINUM "\n",
 		inode);
 
@@ -359,8 +295,21 @@ ffs_dent_walk_lcl(FS_INFO * fs, FFS_DINFO * dinfo, INUM_T inode, int flags,
     load_file.base = load_file.cur = dirbuf;
 
     fs->file_walk(fs, fs_inode, 0, 0,
-		  FS_FLAG_FILE_SLACK | FS_FLAG_FILE_NOID,
-		  load_file_action, (void *) &load_file);
+		  FS_FLAG_FILE_SLACK | FS_FLAG_FILE_NOID |
+		  FS_FLAG_FILE_NOABORT, load_file_action,
+		  (void *) &load_file);
+
+    /* Not all of the directory was copied, so we exit */
+    if (load_file.left > 0) {
+	free(dirbuf);
+	fs_inode_free(fs_inode);
+
+	if (dinfo->depth == 0)
+	    error("Error reading directory contents: %" PRIuINUM "\n",
+		  inode);
+
+	return;
+    }
 
     /* Directory entries are written in chunks of DIRBLKSIZ
      ** determine how many chunks of this size we have to read to
