@@ -2,7 +2,7 @@
 ** fls
 ** The Sleuth Kit 
 **
-** $Date: 2005/04/27 18:09:35 $
+** $Date: 2005/09/02 23:34:03 $
 **
 ** Given an image and directory inode, display the file names and 
 ** directories that exist (both active and deleted)
@@ -14,43 +14,14 @@
 ** Copyright (c) 2002 @stake Inc.  All rights reserved
 **
 ** TCTUTILs
-** Brian Carrier [carrier@cerias.purdue.edu]
 ** Copyright (c) 2001 Brian Carrier.  All rights reserved
 **
-** Redistribution and use in source and binary forms, with or without
-** modification, are permitted provided that the following conditions are
-** met:
 **
-** 1. Redistributions of source code must retain the above copyright notice,
-**    this list of conditions and the following disclaimer.
-** 2. Redistributions in binary form must reproduce the above copyright
-**    notice, this list of conditions and the following disclaimer in the
-**    documentation and/or other materials provided with the distribution.
-** 3. The name of the author may not be used to endorse or promote
-**    products derived from this software without specific prior written
-**    permission.     
-**
-**
-** THIS SOFTWARE IS NOT AFFILIATED WITH PURDUE UNIVERSITY OR THE CENTER FOR
-** EDUCATION IN INFORMATION ASSURANCE AND SECURITY (CERIAS) AND THEY BEAR
-** NO RESPONSIBILITY FOR ITS USE OR MISUSE.
-**
-** 
-** THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
-** WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
-** MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
-**
-** IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
-** INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
-** (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR
-** BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
-** WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
-** OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
-** ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
+** This software is distributed under the Common Public License 1.0
 **
 */
 
-#include "fs_lib.h"
+#include "libfstools.h"
 
 void
 usage()
@@ -90,8 +61,6 @@ usage()
     exit(1);
 }
 
-FILE *logfp;
-
 int
 main(int argc, char **argv)
 {
@@ -107,8 +76,8 @@ main(int argc, char **argv)
     int32_t sec_skew = 0;
     static char *macpre = NULL;
 
-
     progname = argv[0];
+    setlocale(LC_ALL, "");
 
     lclflags = FLS_DIR | FLS_FILE;
 
@@ -162,7 +131,6 @@ main(int argc, char **argv)
 	    break;
 	case 'v':
 	    verbose++;
-	    logfp = stderr;
 	    break;
 	case 'V':
 	    print_version(stdout);
@@ -242,12 +210,6 @@ main(int argc, char **argv)
 	fs = fs_open(img, fstype);
     }
 
-//              if (strchr(argv[optind], '-') != NULL) 
-//                      error ("Invalid inode (%s) type and id are not allowed", 
-//                         argv[optind]);
-//
-//              inode = atoi(argv[optind]);
-//      }
 
     fs_fls(fs, lclflags, inode, flags, macpre, sec_skew);
 
