@@ -1,7 +1,7 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/01/17 22:40:16 $
+ * $Date: 2005/08/13 05:27:45 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -32,7 +32,7 @@ fs_read_block(FS_INFO * fs, DATA_BUF * buf, OFF_T len, DADDR_T addr)
 
     if (len % fs->dev_bsize) {
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fs_read_block: Block read request with length (%"
 		    PRIuOFF ") not a multiple of %d", len, fs->dev_bsize);
 	errno = EIO;
@@ -42,7 +42,7 @@ fs_read_block(FS_INFO * fs, DATA_BUF * buf, OFF_T len, DADDR_T addr)
 
     if (len > buf->size) {
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fs_read_block: Buffer length is too short for read (%"
 		    PRIuOFF " > %u)", len, (int) buf->size);
 
@@ -52,7 +52,7 @@ fs_read_block(FS_INFO * fs, DATA_BUF * buf, OFF_T len, DADDR_T addr)
 
     if (addr > fs->last_block) {
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fs_read_block: File system block address is too large for image %"
 		    PRIuDADDR ")", addr);
 	errno = EFAULT;
@@ -72,7 +72,7 @@ fs_read_block_nobuf(FS_INFO * fs, char *buf, OFF_T len, DADDR_T addr)
 {
     if (len % fs->dev_bsize) {
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fs_read_block_nobuf: Block read request with length (%"
 		    PRIuOFF ") not a multiple of %d", len, fs->dev_bsize);
 	errno = EIO;
@@ -81,7 +81,7 @@ fs_read_block_nobuf(FS_INFO * fs, char *buf, OFF_T len, DADDR_T addr)
 
     if (addr > fs->last_block) {
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "fs_read_block_nobuf: File system block address is too large for image %"
 		    PRIuDADDR ")", addr);
 	errno = EFAULT;
