@@ -2,7 +2,7 @@
 ** fs_tools
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/09/02 23:34:03 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -17,9 +17,13 @@
 #ifndef _FS_TOOLS_H
 #define _FS_TOOLS_H
 
- /*
-  * External interface.
-  */
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+    /*
+     * External interface.
+     */
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -31,22 +35,17 @@
 #include <sys/types.h>
 #include <sys/time.h>
 #include <time.h>
+#include <locale.h>
 
 #include "tsk_os.h"
 #include "tsk_types.h"
 
-#include "aux_lib.h"
-#include "img_lib.h"
+#include "libauxtools.h"
+#include "libimgtools.h"
 
 #include "fs_types.h"
 
 
- /*
-  * Verbose logging.
-  */
-extern FILE *logfp;
-
-
 #ifndef NBBY
 #define NBBY 8
 #endif
@@ -60,13 +59,13 @@ extern FILE *logfp;
 #endif
 
 
-typedef struct FS_INFO FS_INFO;
-typedef struct FS_INODE FS_INODE;
-typedef struct FS_DENT FS_DENT;
-typedef struct FS_DATA FS_DATA;
-typedef struct FS_DATA_RUN FS_DATA_RUN;
-typedef struct FS_NAME FS_NAME;
-typedef struct FS_JENTRY FS_JENTRY;
+    typedef struct FS_INFO FS_INFO;
+    typedef struct FS_INODE FS_INODE;
+    typedef struct FS_DENT FS_DENT;
+    typedef struct FS_DATA FS_DATA;
+    typedef struct FS_DATA_RUN FS_DATA_RUN;
+    typedef struct FS_NAME FS_NAME;
+    typedef struct FS_JENTRY FS_JENTRY;
 
 /* Flags for the return value of inode_walk, block_walk, and dent_walk
  * actions
@@ -75,84 +74,87 @@ typedef struct FS_JENTRY FS_JENTRY;
 #define WALK_STOP	0x1
 
 /* walk action functions */
-typedef uint8_t(*FS_INODE_WALK_FN) (FS_INFO *, FS_INODE *, int, void *);
-typedef uint8_t(*FS_BLOCK_WALK_FN) (FS_INFO *, DADDR_T, char *, int,
-				    void *);
-typedef uint8_t(*FS_DENT_WALK_FN) (FS_INFO *, FS_DENT *, int, void *);
-typedef uint8_t(*FS_FILE_WALK_FN) (FS_INFO *, DADDR_T, char *,
-				   unsigned int, int, void *);
+    typedef uint8_t(*FS_INODE_WALK_FN) (FS_INFO *, FS_INODE *, int,
+					void *);
+    typedef uint8_t(*FS_BLOCK_WALK_FN) (FS_INFO *, DADDR_T, char *, int,
+					void *);
+    typedef uint8_t(*FS_DENT_WALK_FN) (FS_INFO *, FS_DENT *, int, void *);
+    typedef uint8_t(*FS_FILE_WALK_FN) (FS_INFO *, DADDR_T, char *,
+				       unsigned int, int, void *);
 
-typedef uint8_t(*FS_JBLK_WALK_FN) (FS_INFO *, char *, int, void *);
-typedef uint8_t(*FS_JENTRY_WALK_FN) (FS_INFO *, FS_JENTRY *, int, void *);
+    typedef uint8_t(*FS_JBLK_WALK_FN) (FS_INFO *, char *, int, void *);
+    typedef uint8_t(*FS_JENTRY_WALK_FN) (FS_INFO *, FS_JENTRY *, int,
+					 void *);
 
 
 
 
 /* Data structure and action to internally load a file */
-typedef struct {
-    char *base;
-    char *cur;
-    size_t total;
-    size_t left;
-} FS_LOAD_FILE;
+    typedef struct {
+	char *base;
+	char *cur;
+	size_t total;
+	size_t left;
+    } FS_LOAD_FILE;
 
-extern uint8_t load_file_action(FS_INFO *, DADDR_T, char *, unsigned int,
-				int, void *);
+    extern uint8_t load_file_action(FS_INFO *, DADDR_T, char *,
+				    unsigned int, int, void *);
 
 /***************************************************************
  * FS_INFO: Allocated when an image is opened
  */
-struct FS_INFO {
-    IMG_INFO *img_info;
+    struct FS_INFO {
+	IMG_INFO *img_info;
 
-    /* meta data */
-    INUM_T inum_count;		/* number of inodes */
-    INUM_T root_inum;		/* root inode */
-    INUM_T first_inum;		/* first valid inode */
-    INUM_T last_inum;		/* LINUX starts at 1 */
+	/* meta data */
+	INUM_T inum_count;	/* number of inodes */
+	INUM_T root_inum;	/* root inode */
+	INUM_T first_inum;	/* first valid inode */
+	INUM_T last_inum;	/* LINUX starts at 1 */
 
-    /* content */
-    DADDR_T block_count;	/* number of blocks */
-    DADDR_T first_block;	/* in case start at 1 */
-    DADDR_T last_block;		/* in case start at 1 */
-    unsigned int block_size;	/* block size in bytes */
-    unsigned int dev_bsize;	/* size of device blocks */
+	/* content */
+	DADDR_T block_count;	/* number of blocks */
+	DADDR_T first_block;	/* in case start at 1 */
+	DADDR_T last_block;	/* in case start at 1 */
+	unsigned int block_size;	/* block size in bytes */
+	unsigned int dev_bsize;	/* size of device blocks */
 
-    /* Journal */
-    INUM_T journ_inum;		/* Inode of journal */
+	/* Journal */
+	INUM_T journ_inum;	/* Inode of journal */
 
-    uint8_t ftype;		/* type of file system */
-    uint8_t flags;		/* flags for image, see below */
+	uint8_t ftype;		/* type of file system */
+	uint8_t flags;		/* flags for image, see below */
 
-    /* endian order flag - values defined in misc/tsk_endian.h */
-    uint8_t endian;
+	/* endian order flag - values defined in misc/tsk_endian.h */
+	uint8_t endian;
 
 
-    /* file system specific function pointers */
-    void (*block_walk) (FS_INFO *, DADDR_T, DADDR_T, int,
-			FS_BLOCK_WALK_FN, void *);
+	/* file system specific function pointers */
+	void (*block_walk) (FS_INFO *, DADDR_T, DADDR_T, int,
+			    FS_BLOCK_WALK_FN, void *);
 
-    void (*inode_walk) (FS_INFO *, INUM_T, INUM_T, int,
-			FS_INODE_WALK_FN, void *);
-    FS_INODE *(*inode_lookup) (FS_INFO *, INUM_T);
-    void (*istat) (FS_INFO *, FILE *, INUM_T, int, int32_t);
+	void (*inode_walk) (FS_INFO *, INUM_T, INUM_T, int,
+			    FS_INODE_WALK_FN, void *);
+	FS_INODE *(*inode_lookup) (FS_INFO *, INUM_T);
+	void (*istat) (FS_INFO *, FILE *, INUM_T, int, int32_t);
 
-    void (*file_walk) (FS_INFO *, FS_INODE *, uint32_t, uint16_t,
-		       int, FS_FILE_WALK_FN, void *);
+	void (*file_walk) (FS_INFO *, FS_INODE *, uint32_t, uint16_t,
+			   int, FS_FILE_WALK_FN, void *);
 
-    void (*dent_walk) (FS_INFO *, INUM_T, int, FS_DENT_WALK_FN, void *);
+	void (*dent_walk) (FS_INFO *, INUM_T, int, FS_DENT_WALK_FN,
+			   void *);
 
-    void (*jopen) (FS_INFO *, INUM_T);
-    void (*jblk_walk) (FS_INFO *, DADDR_T, DADDR_T, int,
-		       FS_JBLK_WALK_FN, void *);
-    void (*jentry_walk) (FS_INFO *, int, FS_JENTRY_WALK_FN, void *);
+	void (*jopen) (FS_INFO *, INUM_T);
+	void (*jblk_walk) (FS_INFO *, DADDR_T, DADDR_T, int,
+			   FS_JBLK_WALK_FN, void *);
+	void (*jentry_walk) (FS_INFO *, int, FS_JENTRY_WALK_FN, void *);
 
 
-    void (*fsstat) (FS_INFO *, FILE *);
-    void (*fscheck) (FS_INFO *, FILE *);
+	void (*fsstat) (FS_INFO *, FILE *);
+	void (*fscheck) (FS_INFO *, FILE *);
 
-    void (*close) (FS_INFO *);
-};
+	void (*close) (FS_INFO *);
+    };
 
 /* flag for FS_INFO flags */
 #define FS_HAVE_SEQ		0x08
@@ -212,34 +214,34 @@ struct FS_INFO {
  */
 
 /* len = 0 when not being used */
-struct FS_DATA_RUN {
-    FS_DATA_RUN *next;
-    DADDR_T addr;		/* Starting data unit address */
-    DADDR_T len;		/* Length in data units */
-    uint8_t flags;
-};
+    struct FS_DATA_RUN {
+	FS_DATA_RUN *next;
+	DADDR_T addr;		/* Starting data unit address */
+	DADDR_T len;		/* Length in data units */
+	uint8_t flags;
+    };
 #define FS_DATA_FILLER	0x1
 #define FS_DATA_SPARSE	0x2
 
-struct FS_DATA {
-    FS_DATA *next;
-    uint8_t flags;
-    char *name;			/* name of data (if available) */
-    unsigned int nsize;		/* number of allocated bytes for name */
-    uint32_t type;		/* type of attribute */
-    uint16_t id;		/* id of attr, used when duplicate types */
+    struct FS_DATA {
+	FS_DATA *next;
+	uint8_t flags;
+	char *name;		/* name of data (if available) */
+	unsigned int nsize;	/* number of allocated bytes for name */
+	uint32_t type;		/* type of attribute */
+	uint16_t id;		/* id of attr, used when duplicate types */
 
-    OFF_T size;			/* size of data (in bytes) of stream or run */
+	OFF_T size;		/* size of data (in bytes) of stream or run */
 
-    /* Run-List data (non-resident) */
-    FS_DATA_RUN *run;		/* a linked list of data runs */
-    OFF_T runlen;		/* number of bytes that are allocated in
+	/* Run-List data (non-resident) */
+	FS_DATA_RUN *run;	/* a linked list of data runs */
+	OFF_T runlen;		/* number of bytes that are allocated in
 				 * original run (larger than size) */
 
-    /* stream data (resident) */
-    size_t buflen;		/* allocated bytes in buf */
-    uint8_t *buf;		/* buffer for resident data */
-};
+	/* stream data (resident) */
+	size_t buflen;		/* allocated bytes in buf */
+	uint8_t *buf;		/* buffer for resident data */
+    };
 
 #define FS_DATA_INUSE	0x1	// structre in use
 #define FS_DATA_NONRES	0x2	// non-resident
@@ -250,42 +252,42 @@ struct FS_DATA {
 
 
 /* Currently this is only used with NTFS & FAT systems */
-struct FS_NAME {
-    FS_NAME *next;
-    char name[256];
-    INUM_T par_inode;
-    uint32_t par_seq;
-};
+    struct FS_NAME {
+	FS_NAME *next;
+	char name[512];		// Could be in UTF-8 encoding
+	INUM_T par_inode;
+	uint32_t par_seq;
+    };
 
-struct FS_INODE {
-    INUM_T addr;		/* Address of meta data structure */
-    mode_t mode;		/* type and permission */
-    int nlink;			/* link count */
-    OFF_T size;			/* file size */
-    uid_t uid;			/* owner */
-    gid_t gid;			/* group */
-    /* @@@ Need to make these 64-bits ... ? */
-    time_t mtime;		/* last modified */
-    time_t atime;		/* last access */
-    time_t ctime;		/* last status change */
-    time_t crtime;		/* create time (NTFS only: not used by ils) */
-    time_t dtime;		/* delete time (Linux only) */
-    DADDR_T *direct_addr;	/* direct blocks */
-    int direct_count;		/* number of blocks */
-    DADDR_T *indir_addr;	/* indirect blocks */
-    int indir_count;		/* number of blocks */
+    struct FS_INODE {
+	INUM_T addr;		/* Address of meta data structure */
+	mode_t mode;		/* type and permission */
+	int nlink;		/* link count */
+	OFF_T size;		/* file size */
+	uid_t uid;		/* owner */
+	gid_t gid;		/* group */
+	/* @@@ Need to make these 64-bits ... ? */
+	time_t mtime;		/* last modified */
+	time_t atime;		/* last access */
+	time_t ctime;		/* last status change */
+	time_t crtime;		/* create time (NTFS only: not used by ils) */
+	time_t dtime;		/* delete time (Linux only) */
+	DADDR_T *direct_addr;	/* direct blocks */
+	int direct_count;	/* number of blocks */
+	DADDR_T *indir_addr;	/* indirect blocks */
+	int indir_count;	/* number of blocks */
 
-    uint32_t seq;		/* sequence number (NTFS Only) */
-    FS_DATA *attr;		/* additional attributes for NTFS */
-    FS_NAME *name;
-    char *link;			/* used if this is a symbolic link */
+	uint32_t seq;		/* sequence number (NTFS Only) */
+	FS_DATA *attr;		/* additional attributes for NTFS */
+	FS_NAME *name;
+	char *link;		/* used if this is a symbolic link */
 
-    int flags;			/* flags FS_FLAG_META_* */
-};
+	int flags;		/* flags FS_FLAG_META_* */
+    };
 
-extern FS_INODE *fs_inode_alloc(int, int);
-extern FS_INODE *fs_inode_realloc(FS_INODE *, int, int);
-extern void fs_inode_free(FS_INODE *);
+    extern FS_INODE *fs_inode_alloc(int, int);
+    extern FS_INODE *fs_inode_realloc(FS_INODE *, int, int);
+    extern void fs_inode_free(FS_INODE *);
 
 
 
@@ -293,18 +295,21 @@ extern void fs_inode_free(FS_INODE *);
 /************************************************************************* 
  * Directory entries 
  */
-struct FS_DENT {
-    INUM_T inode;		/* inode number */
-    uint8_t ent_type;		/* dir, file etc FS_DENT_??? */
-    uint16_t namlen;		/* length of actual name */
-// @@@ This should be locally defined in each file system 
-    ULONG maxnamlen;		/* size allocated to name */
-    char *name;			/* name of file, directory etc
-				 ** this MUST be NULL terminated */
-    struct FS_INODE *fsi;	/* Inode structure */
-    char *path;			/* prefix to name when recursing */
-    unsigned int pathdepth;	/* current depth of directories */
-};
+    struct FS_DENT {
+	char *name;		/* long / normal name -- could be UTF-8 */
+	ULONG name_max;		/* number of bytes allocated to name */
+
+	char *shrt_name;	/* short version of name (FAT / NTFS only) */
+	ULONG shrt_name_max;	/* number of bytes allocated to short name */
+
+	INUM_T inode;		/* inode number */
+	struct FS_INODE *fsi;	/* Inode structure */
+
+	uint8_t ent_type;	/* dir, file etc FS_DENT_??? */
+
+	char *path;		/* prefix to name when recursing */
+	unsigned int pathdepth;	/* current depth of directories */
+    };
 
 
 /* Type of file that entry is for (ent_type for FS_DENT) */
@@ -323,7 +328,7 @@ struct FS_DENT {
 #define FS_DENT_MAX_STR 15	/* max index for string version of types */
 
 /* ascii representation of above types */
-extern char fs_dent_str[FS_DENT_MAX_STR][2];
+    extern char fs_dent_str[FS_DENT_MAX_STR][2];
 
 /* string that is prepended to orphan FAT & NTFS files when the file
  * name is known, but the parent is not */
@@ -346,7 +351,7 @@ extern char fs_dent_str[FS_DENT_MAX_STR][2];
 #define FS_INODE_MASK    15	/* mask value */
 #define FS_INODE_MAX_STR 15	/* max index for string version of types */
 
-extern char fs_inode_str[FS_INODE_MAX_STR][2];
+    extern char fs_inode_str[FS_INODE_MAX_STR][2];
 
 #define MODE_ISUID 0004000	/* set user id on execution */
 #define MODE_ISGID 0002000	/* set group id on execution */
@@ -367,27 +372,28 @@ extern char fs_inode_str[FS_INODE_MAX_STR][2];
 
 
 /**************** Journal Stuff **********************/
-struct FS_JENTRY {
-    DADDR_T jblk;		/* journal block address */
-    DADDR_T fsblk;		/* fs block that journal entry is about */
-};
+    struct FS_JENTRY {
+	DADDR_T jblk;		/* journal block address */
+	DADDR_T fsblk;		/* fs block that journal entry is about */
+    };
 
 
 
 
 /* function decs */
-extern FS_DENT *fs_dent_alloc(ULONG);
-extern FS_DENT *fs_dent_realloc(FS_DENT *, ULONG);
-extern void fs_dent_free(FS_DENT *);
-extern void fs_dent_print(FILE *, FS_DENT *, int, FS_INFO *, FS_DATA *);
-extern void fs_dent_print_long(FILE *, FS_DENT *, int, FS_INFO *,
-			       FS_DATA *);
-extern void fs_dent_print_mac(FILE *, FS_DENT *, int, FS_INFO *,
-			      FS_DATA * fs_data, char *);
+    extern FS_DENT *fs_dent_alloc(ULONG, ULONG);
+    extern FS_DENT *fs_dent_realloc(FS_DENT *, ULONG);
+    extern void fs_dent_free(FS_DENT *);
+    extern void fs_dent_print(FILE *, FS_DENT *, int, FS_INFO *,
+			      FS_DATA *);
+    extern void fs_dent_print_long(FILE *, FS_DENT *, int, FS_INFO *,
+				   FS_DATA *);
+    extern void fs_dent_print_mac(FILE *, FS_DENT *, int, FS_INFO *,
+				  FS_DATA * fs_data, char *);
 
-extern void make_ls(mode_t, char *, int);
-extern void fs_print_day(FILE *, time_t);
-extern void fs_print_time(FILE *, time_t);
+    extern void make_ls(mode_t, char *, int);
+    extern void fs_print_day(FILE *, time_t);
+    extern void fs_print_time(FILE *, time_t);
 
 /*
 ** Is this string a "." or ".."
@@ -400,23 +406,24 @@ extern void fs_print_time(FILE *, time_t);
 /**************************************************************8
  * Generic routines.
  */
-extern FS_INFO *fs_open(IMG_INFO *, const char *);
+    extern FS_INFO *fs_open(IMG_INFO *, const char *);
 
 /* fs_io routines */
-extern OFF_T fs_read_block(FS_INFO *, DATA_BUF *, OFF_T, DADDR_T);
-extern OFF_T fs_read_block_nobuf(FS_INFO *, char *, OFF_T, DADDR_T);
+    extern OFF_T fs_read_block(FS_INFO *, DATA_BUF *, OFF_T, DADDR_T);
+    extern OFF_T fs_read_block_nobuf(FS_INFO *, char *, OFF_T, DADDR_T);
 #define fs_read_random(fsi, buf, len, offs)	\
 	(fsi)->img_info->read_random((fsi)->img_info, (buf), (len), (offs))
 
 
 /* Specific file system routines */
-extern FS_INFO *ext2fs_open(IMG_INFO *, unsigned char ftype, uint8_t);
-extern FS_INFO *fatfs_open(IMG_INFO *, unsigned char ftype, uint8_t);
-extern FS_INFO *ffs_open(IMG_INFO *, unsigned char ftype, uint8_t);
-extern FS_INFO *ntfs_open(IMG_INFO *, unsigned char ftype, uint8_t);
-extern FS_INFO *rawfs_open(IMG_INFO *, unsigned char ftype);
-extern FS_INFO *swapfs_open(IMG_INFO *, unsigned char ftype);
-extern FS_INFO *iso9660_open(IMG_INFO *, unsigned char, uint8_t);
+    extern FS_INFO *ext2fs_open(IMG_INFO *, unsigned char, uint8_t);
+    extern FS_INFO *fatfs_open(IMG_INFO *, unsigned char, uint8_t);
+    extern FS_INFO *ffs_open(IMG_INFO *, unsigned char, uint8_t);
+    extern FS_INFO *ntfs_open(IMG_INFO *, unsigned char, uint8_t);
+    extern FS_INFO *rawfs_open(IMG_INFO *, unsigned char);
+    extern FS_INFO *swapfs_open(IMG_INFO *, unsigned char);
+    extern FS_INFO *iso9660_open(IMG_INFO *, unsigned char, uint8_t);
+    extern FS_INFO *hfs_open(IMG_INFO *, unsigned char, uint8_t);
 
 
 // Endian macros - actual functions in misc/
@@ -427,9 +434,10 @@ extern FS_INFO *iso9660_open(IMG_INFO *, unsigned char, uint8_t);
 #define guessu32(fs, x, mag)   \
 	guess_end_u32(&(fs->endian), (x), (mag))
 
-
+#ifdef __cplusplus
+}
+#endif
 #endif
-
 /* LICENSE
  * .ad
  * .fi
