@@ -2,7 +2,7 @@
 ** fs_types
 ** The Sleuth Kit 
 **
-** $Date: 2005/06/13 19:27:17 $
+** $Date: 2005/09/02 23:34:03 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -14,10 +14,13 @@
 #ifndef _FS_TYPES_H
 #define _FS_TYPES_H
 
-extern char fs_parse_type(const char *);
-extern void fs_print_types(FILE *);
-extern char *fs_get_type(char);
-extern void print_version();
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+    extern char fs_parse_type(const char *);
+    extern void fs_print_types(FILE *);
+    extern char *fs_get_type(char);
 
 /*
 ** the most-sig-nibble is the file system type, which indictates which
@@ -64,4 +67,10 @@ extern void print_version();
 #define ISO9660_TYPE		0x70
 #define ISO9660			0x70
 
+#define HFS_TYPE		0x80
+#define HFS			0x80
+
+#ifdef __cplusplus
+}
+#endif
 #endif
