@@ -2,7 +2,7 @@
 ** fsstat
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/04 05:41:26 $
+** $Date: 2005/09/02 23:34:03 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -10,11 +10,12 @@
 ** TASK
 ** Copyright (c) 2002 Brian Carrier, @stake Inc. All Rights reserved
 **
+**
+** This software is distributed under the Common Public License 1.0
+**
 */
 #include "fs_tools.h"
 
-FILE *logfp;
-
 static void
 usage()
 {
@@ -47,6 +48,7 @@ main(int argc, char **argv)
     uint8_t type = 0;
 
     progname = argv[0];
+    setlocale(LC_ALL, "");
 
     while ((ch = getopt(argc, argv, "f:i:o:tvV")) > 0) {
 	switch (ch) {
@@ -73,7 +75,6 @@ main(int argc, char **argv)
 
 	case 'v':
 	    verbose++;
-	    logfp = stderr;
 	    break;
 
 	case 'V':
