@@ -2,7 +2,7 @@
 ** icat 
 ** The Sleuth Kit 
 **
-** $Date: 2005/05/18 00:41:57 $
+** $Date: 2005/09/02 19:53:28 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -22,9 +22,8 @@
  *	Yorktown Heights, NY 10598, USA
  --*/
 
-#include "fs_lib.h"
+#include "libfstools.h"
 
-FILE *logfp;
 
 /* usage - explain and terminate */
 
@@ -67,6 +66,7 @@ main(int argc, char **argv)
     int id_used = 0;
 
     progname = argv[0];
+    setlocale(LC_ALL, "");
 
     while ((ch = getopt(argc, argv, "f:hi:o:rsvV")) > 0) {
 	switch (ch) {
@@ -94,7 +94,6 @@ main(int argc, char **argv)
 	    break;
 	case 'v':
 	    verbose++;
-	    logfp = stderr;
 	    break;
 	case 'V':
 	    print_version(stdout);
