@@ -2,7 +2,7 @@
 ** icat_lib 
 ** The Sleuth Kit 
 **
-** $Date: 2005/03/15 21:17:21 $
+** $Date: 2005/06/13 19:27:17 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -29,8 +29,8 @@
 /* Call back action for file_walk
  */
 static uint8_t
-icat_action(FS_INFO * fs, DADDR_T addr, char *buf, int size,
-	    int flags, void *ptr)
+icat_action(FS_INFO * fs, DADDR_T addr, char *buf,
+	    unsigned int size, int flags, void *ptr)
 {
     if (size == 0)
 	return WALK_CONT;
@@ -42,8 +42,8 @@ icat_action(FS_INFO * fs, DADDR_T addr, char *buf, int size,
 }
 
 uint8_t
-fs_icat(FS_INFO * fs, uint8_t lclflags, INUM_T inum, int type, int id,
-	int flags)
+fs_icat(FS_INFO * fs, uint8_t lclflags, INUM_T inum, uint32_t type,
+	uint16_t id, int flags)
 {
     FS_INODE *inode;
 
