@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/09/02 19:53:28 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved 
@@ -24,10 +24,7 @@
  *	Yorktown Heights, NY 10598, USA
  --*/
 
-#include "fs_lib.h"
-
-FILE *logfp;
-
+#include "libfstools.h"
 
 
 /* atoinum - convert string to inode number */
@@ -105,6 +102,7 @@ main(int argc, char **argv)
     int32_t sec_skew = 0;
 
     progname = argv[0];
+    setlocale(LC_ALL, "");
 
     /*
      * Provide convenience options for the most commonly selected feature
@@ -143,7 +141,6 @@ main(int argc, char **argv)
 	    break;
 	case 'v':
 	    verbose++;
-	    logfp = stderr;
 	    break;
 	case 'V':
 	    print_version(stdout);
