@@ -17,7 +17,6 @@
 ** Copyright (c) 1997,1998,1999, International Business Machines
 ** Corporation and others. All Rights Reserved.
 */
-
 /* TCT
  * LICENSE
  *      This software is distributed under the IBM Public License.
@@ -27,7 +26,6 @@
  *      P.O. Box 704
  *      Yorktown Heights, NY 10598, USA
  --*/
-
 /*
 ** You may distribute the Sleuth Kit, or other software that incorporates
 ** part of all of the Sleuth Kit, in object code form under a license agreement,
@@ -56,22 +54,18 @@
 **     b) a copy of the IBM Public License ver. 1.0 must be included with 
 **        each copy of the program.
 */
-
 #include "fs_tools.h"
 #include "fs_types.h"
 #include "iso9660.h"
-
 #include "mymalloc.h"
 #include "error.h"
-
 #include "fs_data.h"
-
 #include <ctype.h>
 #include <netinet/in.h>
-
 /*
  * Convert a UNICODE string to an UTF-8 string
  */
+
 void
 uni2utf8(char *ucs2, int ucs2len, char *utf8, int utf8len)
 {
@@ -142,7 +136,7 @@ parse_rockridge(FS_INFO * fs, char *buf, int count)
     char *end = buf + count - 1;
 
     if (verbose)
-	fprintf(logfp, "parse_rockridge: count is: %" PRIu32 " ", count);
+	fprintf(stderr, "parse_rockridge: count is: %" PRIu32 " ", count);
 
     rr = (rockridge_ext *) mymalloc(sizeof(rockridge_ext));
 
@@ -225,7 +219,7 @@ iso9660_get_dentrys(FS_INFO * fs, OFF_T offs, int count, int type,
     int fn_skip;		/* filename skip size */
 
     if (verbose)
-	fprintf(logfp, "iso9660_get_dentrys: fs: %" PRIu32 " offs: %"
+	fprintf(stderr, "iso9660_get_dentrys: fs: %" PRIu32 " offs: %"
 		PRIu32 " count: %" PRIu32 " type: %" PRIu32 " fn: %"
 		PRIu32 "\n", (int) fs, (int) offs, count, type, (int) fn);
 
@@ -441,7 +435,7 @@ iso9660_find_inodes(ISO_INFO * iso)
     off_t extent;		/* offset of extent for current directory */
 
     if (verbose)
-	fprintf(logfp, "iso9660_find_inodes: iso: %" PRIu32 "\n",
+	fprintf(stderr, "iso9660_find_inodes: iso: %" PRIu32 "\n",
 		(int) iso);
 
     /* initialize in case repeatedly called */
@@ -557,7 +551,7 @@ iso9660_dinode_load(ISO_INFO * iso, INUM_T inum)
     in_node *n;
 
     if (verbose)
-	fprintf(logfp, "iso9660_dinode_load: iso: %" PRIu32
+	fprintf(stderr, "iso9660_dinode_load: iso: %" PRIu32
 		" inum: %" PRIu32 "\n", (int) iso, (int) inum);
 
     /*
@@ -586,7 +580,7 @@ iso9660_dinode_copy(ISO_INFO * iso, FS_INODE * fs_inode)
     struct tm t;
 
     if (verbose)
-	fprintf(logfp, "iso9660_dinode_copy: iso: %" PRIu32
+	fprintf(stderr, "iso9660_dinode_copy: iso: %" PRIu32
 		" inode: %" PRIu32 "\n", (int) iso, (int) fs_inode);
 
     fs_inode->addr = iso->dinum;
@@ -627,7 +621,7 @@ iso9660_inode_lookup(FS_INFO * fs, INUM_T inum)
     FS_INODE *fs_inode = fs_inode_alloc(ISO9660_NDADDR, ISO9660_NIADDR);
 
     if (verbose)
-	fprintf(logfp, "iso9660_inode_lookup: iso: %" PRIu32
+	fprintf(stderr, "iso9660_inode_lookup: iso: %" PRIu32
 		" inum: %" PRIu32 "\n", (int) iso, (int) inum);
 
     iso9660_dinode_load(iso, inum);
@@ -647,7 +641,7 @@ iso9660_inode_walk(FS_INFO * fs, INUM_T start, INUM_T last, int flags,
     int myflags;
 
     if (verbose)
-	fprintf(logfp, "iso9660_inode_walk: iso: %" PRIu32
+	fprintf(stderr, "iso9660_inode_walk: iso: %" PRIu32
 		" start: %" PRIu32 " last: %" PRIu32 " flags: %"
 		PRIu32 " action: %" PRIu32 " ptr: %" PRIu32
 		"\n", (int) fs, (int) start, (int) last, (int) flags,
@@ -703,7 +697,7 @@ iso9660_is_block_alloc(FS_INFO * fs, int blk_num)
     int file_size = 0;
 
     if (verbose)
-	fprintf(logfp, "iso9660_is_block_alloc: fs: %" PRIu32
+	fprintf(stderr, "iso9660_is_block_alloc: fs: %" PRIu32
 		" blk_num: %" PRIu32 "\n", (int) fs, blk_num);
 
     while (in) {
@@ -736,7 +730,7 @@ iso9660_block_walk(FS_INFO * fs, DADDR_T start, DADDR_T last, int flags,
     int myflags = 0;
 
     if (verbose)
-	fprintf(logfp, "iso9660_block_walk: fs: %" PRIu32
+	fprintf(stderr, "iso9660_block_walk: fs: %" PRIu32
 		" start: %" PRIu32 " last: %" PRIu32 " flags: %"
 		PRIu32 " action: %" PRIu32 " ptr: %" PRIu32
 		"\n", (int) fs, (int) start, (int) last, (int) flags,
@@ -752,7 +746,7 @@ iso9660_block_walk(FS_INFO * fs, DADDR_T start, DADDR_T last, int flags,
 	error("%s: invalid last block number: %lu", myname, (ULONG) last);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"isofs_block_walk: Block Walking %lu to %lu\n",
 		(ULONG) start, (ULONG) last);
 
@@ -795,7 +789,7 @@ iso9660_file_walk(FS_INFO * fs, FS_INODE * inode, uint32_t type,
     DADDR_T addr;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"iso9660_file_walk: inode: %" PRIuINUM " type: %" PRIu32
 		" id: %" PRIu16 " flags: %X\n", inode->addr, type, id,
 		flags);
@@ -867,7 +861,7 @@ iso9660_fsstat(FS_INFO * fs, FILE * hFile)
     svd_node *s = iso->svd;
 
     if (verbose)
-	fprintf(logfp, "iso9660_fsstat: fs: %" PRIu32 " \
+	fprintf(stderr, "iso9660_fsstat: fs: %" PRIu32 " \
 			hFile: %" PRIu32 "\n", (int) fs, (int) hFile);
 
     i = 0;
@@ -1077,7 +1071,7 @@ make_unix_perm(FS_INFO * fs, iso9660_dentry * dd)
     ISO_INFO *iso = (ISO_INFO *) fs;
 
     if (verbose)
-	fprintf(logfp, "make_unix_perm: fs: %" PRIu32
+	fprintf(stderr, "make_unix_perm: fs: %" PRIu32
 		" dd: %" PRIu32 "\n", (int) fs, (int) dd);
 
     perm[10] = '\0';
@@ -1364,7 +1358,7 @@ get_vol_desc(FS_INFO * fs)
 
     if (strncmp(vd.magic, ISO9660_MAGIC, 5)) {
 	if (verbose)
-	    fprintf(logfp, "%s Bad volume descriptor: \
+	    fprintf(stderr, "%s Bad volume descriptor: \
 			         Magic number is not CD001", myname);
 	return 0;
     }
@@ -1453,7 +1447,7 @@ get_vol_desc(FS_INFO * fs)
 
 	if (strncmp(vd.magic, ISO9660_MAGIC, 5)) {
 	    if (verbose)
-		fprintf(logfp, "%s Bad volume descriptor: \
+		fprintf(stderr, "%s Bad volume descriptor: \
 				         Magic number is not CD001", myname);
 	    return 0;
 	}
@@ -1543,7 +1537,7 @@ iso9660_open(IMG_INFO * img_info, unsigned char ftype, uint8_t test)
     int len;
 
     if (verbose) {
-	fprintf(logfp, "iso9660_open img_info: %" PRIu32
+	fprintf(stderr, "iso9660_open img_info: %" PRIu32
 		" ftype: %" PRIu8 " test: %" PRIu8 "\n", (int) img_info,
 		ftype, test);
     }
