@@ -2,7 +2,7 @@
 ** ntfs
 ** The Sleuth Kit 
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/10/13 04:15:22 $
 **
 ** Content and meta data layer support for the NTFS file system
 **
@@ -12,10 +12,16 @@
 ** TASK
 ** Copyright (c) 2002 Brian Carrier, @stake Inc.  All rights reserved
 **
+**
+** This software is distributed under the Common Public License 1.0
+**
+** Unicode added with support from I.D.E.A.L. Technology Corp (Aug '05)
+**
 */
 #include "fs_tools.h"
 #include "fs_data.h"
 #include "ntfs.h"
+#include "fs_unicode.h"
 
 #include <ctype.h>
 
@@ -133,7 +139,7 @@ ntfs_dinode_lookup(NTFS_INFO * ntfs, ntfs_mft * mft, INUM_T mftnum)
 
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"ntfs_dinode_lookup: Processing MFT %" PRIuINUM "\n",
 		mftnum);
 
@@ -184,7 +190,7 @@ ntfs_dinode_lookup(NTFS_INFO * ntfs, ntfs_mft * mft, INUM_T mftnum)
 	    if (offset < run_len) {
 
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "ntfs_dinode_lookup: Found in offset: %"
 			    PRIuDADDR "  size: %" PRIuDADDR " at offset: %"
 			    PRIuOFF "\n", data_run->addr, data_run->len,
@@ -197,7 +203,7 @@ ntfs_dinode_lookup(NTFS_INFO * ntfs, ntfs_mft * mft, INUM_T mftnum)
 		if (run_len < offset + ntfs->mft_rsize_b) {
 
 		    if (verbose)
-			fprintf(logfp,
+			fprintf(stderr,
 				"ntfs_dinode_lookup: Entry crosses run border\n");
 
 		    if (data_run->next == NULL)
@@ -214,7 +220,7 @@ ntfs_dinode_lookup(NTFS_INFO * ntfs, ntfs_mft * mft, INUM_T mftnum)
 		/* Assign address of where the MFT entry starts */
 		mftaddr_b = data_run->addr * ntfs->csize_b + offset;
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "ntfs_dinode_lookup: Entry address at: %"
 			    PRIuOFF "\n", mftaddr_b);
 		break;
@@ -323,7 +329,7 @@ ntfs_dinode_lookup(NTFS_INFO * ntfs, ntfs_mft * mft, INUM_T mftnum)
 	old_val = (uint8_t *) ((uintptr_t) mft + offset);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_dinode_lookup: upd_seq %i   Replacing: %.4"
 		    PRIx16 "   With: %.4" PRIx16 "\n", i, getu16(fs,
 								 old_val),
@@ -465,7 +471,7 @@ ntfs_make_data_run(NTFS_INFO * ntfs, ntfs_runlist * runlist,
 	for (i = 0, data_run->len = 0; i < NTFS_RUNL_LENSZ(run); i++) {
 	    data_run->len |= (run->buf[idx++] << (i * 8));
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"ntfs_make_data_run: Len idx: %i cur: %" PRIu8
 			" (%" PRIx8 ") tot: %" PRIuDADDR " (%" PRIxDADDR
 			")\n", i, run->buf[idx - 1], run->buf[idx - 1],
@@ -482,7 +488,7 @@ ntfs_make_data_run(NTFS_INFO * ntfs, ntfs_runlist * runlist,
 	    //data_run->addr |= (run->buf[idx++] << (i * 8));
 	    offset |= (run->buf[idx++] << (i * 8));
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"ntfs_make_data_run: Off idx: %i cur: %" PRIu8
 			" (%" PRIx8 ") tot: %" PRIuDADDR " (%" PRIxDADDR
 			")\n", i, run->buf[idx - 1], run->buf[idx - 1],
@@ -496,7 +502,7 @@ ntfs_make_data_run(NTFS_INFO * ntfs, ntfs_runlist * runlist,
 	}
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_make_data_run: Signed offset: %" PRIdDADDR
 		    " Previous address: %" PRIdDADDR "\n", offset,
 		    prev_addr);
@@ -516,7 +522,7 @@ ntfs_make_data_run(NTFS_INFO * ntfs, ntfs_runlist * runlist,
 	    data_run->flags |= FS_DATA_SPARSE;
 	    data_run->addr = 0;
 	    if (verbose)
-		fprintf(logfp, "ntfs_make_data_run: Sparse Run\n");
+		fprintf(stderr, "ntfs_make_data_run: Sparse Run\n");
 	}
 
 	/* A Sparse file has a run with an offset of 0
@@ -536,7 +542,7 @@ ntfs_make_data_run(NTFS_INFO * ntfs, ntfs_runlist * runlist,
 	else {
 	    data_run->flags |= FS_DATA_SPARSE;
 	    if (verbose)
-		fprintf(logfp, "ntfs_make_data_run: Sparse Run\n");
+		fprintf(stderr, "ntfs_make_data_run: Sparse Run\n");
 	}
 
 
@@ -586,7 +592,7 @@ ntfs_data_walk(NTFS_INFO * ntfs, INUM_T inum, FS_DATA * fs_data,
     int myflags;
 
     if (verbose)
-	fprintf(logfp, "ntfs_data_walk: Processing file %" PRIuINUM "\n",
+	fprintf(stderr, "ntfs_data_walk: Processing file %" PRIuINUM "\n",
 		inum);
 
     /* Process the resident buffer 
@@ -615,10 +621,17 @@ ntfs_data_walk(NTFS_INFO * ntfs, INUM_T inum, FS_DATA * fs_data,
 	FS_DATA_RUN *fs_data_run;
 
 
-	if (((flags & FS_FLAG_FILE_NOABORT) == 0) &&
-	    (fs_data->flags & FS_DATA_COMP)) {
-	    error
-		("ERROR: TSK Cannot uncompress NTFS compressed files - aborting");
+	if (fs_data->flags & FS_DATA_COMP) {
+	    if ((flags & FS_FLAG_FILE_NOABORT) == 0) {
+		error
+		    ("ERROR: TSK Cannot uncompress NTFS compressed files - aborting");
+	    }
+	    else {
+		if (verbose)
+		    fprintf(stderr,
+			    "ERROR: TSK Cannot uncompress NTFS compressed files - aborting");
+		return;
+	    }
 	}
 
 
@@ -663,7 +676,7 @@ ntfs_data_walk(NTFS_INFO * ntfs, INUM_T inum, FS_DATA * fs_data,
 		if (addr > fs->last_block) {
 		    if (flags & FS_FLAG_FILE_NOABORT) {
 			if (verbose) {
-			    fprintf(logfp,
+			    fprintf(stderr,
 				    "Invalid address in run (too large): %"
 				    PRIuDADDR "", addr);
 			}
@@ -744,8 +757,7 @@ ntfs_data_walk(NTFS_INFO * ntfs, INUM_T inum, FS_DATA * fs_data,
 
 
 /* 
- * An attribute sequence is a linked list all of the attributes for a
- * MFT entry.
+ * An attribute sequence is a linked list of the attributes in an MFT entry
  * 
  * This function takes a pointer to the beginning of the sequence,
  * examines each attribute and adds the data to the appropriate fields
@@ -762,12 +774,12 @@ ntfs_proc_attrseq(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 {
     ntfs_attr *attr = attrseq;
     FS_DATA *fs_data_attrl = NULL, *fs_data = NULL;
-    char name[NTFS_MAXNAMLEN + 1];
+    char name[NTFS_MAXNAMLEN_UTF8 + 1];
     OFF_T runlen;
     FS_INFO *fs = (FS_INFO *) & ntfs->fs_info;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"ntfs_proc_attrseq: Processing entry %" PRIuINUM
 		"\n", fs_inode->addr);
 
@@ -777,9 +789,48 @@ ntfs_proc_attrseq(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 	 (getu32(fs, attr->len) > 0 &&
 	  (getu32(fs, attr->type) != 0xffffffff));
 	 attr = (ntfs_attr *) ((uintptr_t) attr + getu32(fs, attr->len))) {
+
+	UTF16 *name16;
+	UTF8 *name8;
+	int retVal;
+
 	/* Get the type of this attribute */
 	uint32_t type = getu32(fs, attr->type);
 
+	/* Copy the name and convert it to UTF8 */
+	if (attr->nlen) {
+
+	    name16 =
+		(UTF16 *) ((uintptr_t) attr + getu16(fs, attr->name_off));
+	    name8 = (UTF8 *) name;
+
+	    retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				    (UTF16 *) ((uintptr_t) name16 +
+					       attr->nlen * 2), &name8,
+				    (UTF8 *) ((uintptr_t) name8 +
+					      sizeof(name)),
+				    lenientConversion);
+
+	    if (retVal != conversionOK) {
+		error
+		    ("Error converting NTFS attribute name to UTF8: %d %d",
+		     retVal, fs_inode->addr);
+	    }
+
+	    /* Make sure it is NULL Terminated */
+	    if ((uintptr_t) name8 > (uintptr_t) name + sizeof(name))
+		name[sizeof(name)] = '\0';
+	    else
+		*name8 = '\0';
+	}
+	/* Call the unnamed $Data attribute, $Data */
+	else if (type == NTFS_ATYPE_DATA) {
+	    strncpy(name, "$Data", NTFS_MAXNAMLEN_UTF8 + 1);
+	}
+	else {
+	    strncpy(name, "N/A", NTFS_MAXNAMLEN_UTF8 + 1);
+	}
+
 
 	/* 
 	 * For resident attributes, we will copy the buffer into
@@ -788,20 +839,8 @@ ntfs_proc_attrseq(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 	 */
 	if (attr->res == NTFS_MFT_RES) {
 
-	    /* Copy the name into ASCII */
-	    if (attr->nlen)
-		uni2ascii((char *) ((uintptr_t) attr +
-				    getu16(fs, attr->name_off)),
-			  attr->nlen, name, sizeof(name));
-
-	    /* Call the unnamed $Data attribute, $Data */
-	    else if (type == NTFS_ATYPE_DATA)
-		strncpy(name, "$Data", NTFS_MAXNAMLEN + 1);
-	    else
-		strncpy(name, "N/A", NTFS_MAXNAMLEN + 1);
-
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"ntfs_proc_attrseq: Resident Attribute in %"
 			PRIuINUM " Type: %" PRIu32 " Id: %" PRIu16
 			" Name: %s\n", ntfs->mnum, type, getu16(fs,
@@ -826,29 +865,16 @@ ntfs_proc_attrseq(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 	else {
 	    FS_DATA_RUN *fs_data_run;
 	    uint8_t data_flag = 0;
-	    uint16_t id;
-
-	    /* Copy the name */
-	    if (attr->nlen)
-		uni2ascii((char *) ((uintptr_t) attr +
-				    getu16(fs, attr->name_off)),
-			  attr->nlen, name, sizeof(name));
-
-	    else if (type == NTFS_ATYPE_DATA)
-		strncpy(name, "$Data", NTFS_MAXNAMLEN + 1);
-	    else
-		strncpy(name, "N/A", NTFS_MAXNAMLEN + 1);
-
-
-	    id = getu16(fs, attr->id);
+	    uint16_t id = getu16(fs, attr->id);
 
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"ntfs_proc_attrseq: Non-Resident Attribute in %"
 			PRIuINUM " Type: %" PRIu32 " Id: %" PRIu16
 			" Name: %s  Start VCN: %" PRIu64 "\n", ntfs->mnum,
 			type, id, name, getu64(fs, attr->c.nr.start_vcn));
 
+
 	    /* convert the run to generic form */
 	    fs_data_run = ntfs_make_data_run(ntfs,
 					     (ntfs_runlist *) ((uintptr_t)
@@ -893,11 +919,10 @@ ntfs_proc_attrseq(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 			(strcmp(fs_data2->name, name) == 0)) {
 			id = fs_data2->id;
 			if (verbose)
-			    fprintf(logfp,
+			    fprintf(stderr,
 				    "ntfs_proc_attrseq: Updating id from 0 to %"
 				    PRIu16 "\n", id);
 
-
 			break;
 		    }
 		    fs_data2 = fs_data2->next;
@@ -951,6 +976,8 @@ ntfs_proc_attrseq(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 	else if (type == NTFS_ATYPE_FNAME) {
 	    ntfs_attr_fname *fname;
 	    FS_NAME *fs_name;
+	    UTF16 *name16;
+	    UTF8 *name8;
 
 	    if (attr->res != NTFS_MFT_RES)
 		error("File Name Attribute is not resident!");
@@ -981,8 +1008,27 @@ ntfs_proc_attrseq(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 		fs_name->next = NULL;
 	    }
 
-	    uni2ascii((char *) &fname->name, fname->nlen, fs_name->name,
-		      256);
+	    name16 = (UTF16 *) & fname->name;
+	    name8 = (UTF8 *) fs_name->name;
+
+	    retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				    (UTF16 *) ((uintptr_t) name16 +
+					       fname->nlen * 2), &name8,
+				    (UTF8 *) ((uintptr_t) name8 +
+					      sizeof(fs_name->name)),
+				    lenientConversion);
+
+	    if (retVal != conversionOK) {
+		error("Error converting NTFS name to UTF8: %d", retVal);
+	    }
+
+	    /* Make sure it is NULL Terminated */
+	    if ((uintptr_t) name8 >
+		(uintptr_t) fs_name->name + sizeof(fs_name->name))
+		fs_name->name[sizeof(fs_name->name)] = '\0';
+	    else
+		*name8 = '\0';
+
 	    fs_name->par_inode = getu48(fs, fname->par_ref);
 	    fs_name->par_seq = getu16(fs, fname->par_seq);
 
@@ -1102,7 +1148,7 @@ ntfs_proc_attrlist(NTFS_INFO * ntfs, FS_INODE * fs_inode,
     uint16_t histcnt = 0;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"ntfs_proc_attrlist: Processing entry %" PRIuINUM "\n",
 		fs_inode->addr);
 
@@ -1164,7 +1210,7 @@ ntfs_proc_attrlist(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 	id = getu16(fs, list->id);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_proc_attrlist: mft: %" PRIuINUM " type %" PRIu32
 		    " id %" PRIu16 "  VCN: %" PRIu64 "\n", mftnum, type,
 		    id, getu64(fs, list->start_vcn));
@@ -1186,7 +1232,7 @@ ntfs_proc_attrlist(NTFS_INFO * ntfs, FS_INODE * fs_inode,
 	    else if (verbose) {
 		/* this case can easily occur if the attribute list was non-resident and the cluster has been reallocated */
 
-		fprintf(logfp,
+		fprintf(stderr,
 			"Invalid MFT file reference (%" PRIuINUM
 			") in the unallocated attribute list of MFT %"
 			PRIuINUM "", mftnum, ntfs->mnum);
@@ -1404,7 +1450,30 @@ ntfs_attrname_lookup(FS_INFO * fs, uint16_t type, char *name, int len)
 
     while (getu32(fs, attrdef->type)) {
 	if (getu32(fs, attrdef->type) == type) {
-	    uni2ascii((char *) attrdef->label, 128, name, len);
+
+	    UTF16 *name16 = (UTF16 *) attrdef->label;
+	    UTF8 *name8 = (UTF8 *) name;
+	    int retVal;
+
+	    retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				    (UTF16 *) ((uintptr_t) name16 +
+					       sizeof(attrdef->label)),
+				    &name8,
+				    (UTF8 *) ((uintptr_t) name8 + len),
+				    lenientConversion);
+
+	    if (retVal != conversionOK) {
+		error
+		    ("Error converting NTFS attribute def label to UTF8: %d",
+		     retVal);
+	    }
+
+	    /* Make sure it is NULL Terminated */
+	    if ((uintptr_t) name8 > (uintptr_t) name + len)
+		name[len] = '\0';
+	    else
+		*name8 = '\0';
+
 	    return;
 	}
 	attrdef++;
@@ -1719,7 +1788,7 @@ ntfs_fsstat(FS_INFO * fs, FILE * hFile)
     NTFS_INFO *ntfs = (NTFS_INFO *) fs;
     FS_INODE *fs_inode;
     FS_DATA *fs_data;
-    char asc[128];
+    char asc[512];
     ntfs_attrdef *attrdeftmp;
 
     fprintf(hFile, "FILE SYSTEM INFORMATION\n");
@@ -1748,7 +1817,28 @@ ntfs_fsstat(FS_INFO * fs, FILE * hFile)
 	error("Volume Name attribute not found in $Volume");
 
     if ((fs_data->flags & FS_DATA_RES) && (fs_data->size)) {
-	uni2ascii((char *) fs_data->buf, fs_data->size, asc, 128);
+
+	UTF16 *name16 = (UTF16 *) fs_data->buf;
+	UTF8 *name8 = (UTF8 *) asc;
+	int retVal;
+
+	retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				(UTF16 *) ((uintptr_t) name16 +
+					   (int) fs_data->size), &name8,
+				(UTF8 *) ((uintptr_t) name8 + sizeof(asc)),
+				lenientConversion);
+
+	if (retVal != conversionOK) {
+	    error("Error converting NTFS Volume label to UTF8: %d",
+		  retVal);
+	}
+
+	/* Make sure it is NULL Terminated */
+	if ((uintptr_t) name8 > (uintptr_t) asc + sizeof(asc))
+	    asc[sizeof(asc)] = '\0';
+	else
+	    *name8 = '\0';
+
 	fprintf(hFile, "Volume Name: %s\n", asc);
     }
 
@@ -1807,11 +1897,31 @@ ntfs_fsstat(FS_INFO * fs, FILE * hFile)
     attrdeftmp = ntfs->attrdef;
 
     while (getu32(fs, attrdeftmp->type)) {
-	uni2ascii((char *) attrdeftmp->label, 128, asc, 128);
+	UTF16 *name16 = (UTF16 *) attrdeftmp->label;
+	UTF8 *name8 = (UTF8 *) asc;
+	int retVal;
+
+	retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+				(UTF16 *) ((uintptr_t) name16 +
+					   sizeof(attrdeftmp->label)),
+				&name8,
+				(UTF8 *) ((uintptr_t) name8 + sizeof(asc)),
+				lenientConversion);
+
+	if (retVal != conversionOK) {
+	    error("Error converting NTFS attribute def label to UTF8: %d",
+		  retVal);
+	}
+
+	/* Make sure it is NULL Terminated */
+	if ((uintptr_t) name8 > (uintptr_t) asc + sizeof(asc))
+	    asc[sizeof(asc)] = '\0';
+	else
+	    *name8 = '\0';
+
 	fprintf(hFile, "%s (%" PRIu32 ")   ",
 		asc, getu32(fs, attrdeftmp->type));
 
-
 	if ((getu64(fs, attrdeftmp->minsize) == 0) &&
 	    (getu64(fs, attrdeftmp->maxsize) == 0xffffffffffffffffULL)) {
 
@@ -2222,9 +2332,9 @@ ntfs_istat(FS_INFO * fs, FILE * hFile, INUM_T inum, int numblock,
     fprintf(hFile, "\nAttributes: \n");
     while ((fs_data) && (fs_data->flags & FS_DATA_INUSE)) {
 
-	char type[256];
+	char type[512];
 
-	ntfs_attrname_lookup(fs, fs_data->type, type, 256);
+	ntfs_attrname_lookup(fs, fs_data->type, type, 512);
 
 	printf("Type: %s (%" PRIu32 "-%" PRIu16
 	       ")   Name: %s   %sResident%s%s%s   size: %" PRIuOFF "\n",
@@ -2505,11 +2615,11 @@ ntfs_open(IMG_INFO * img_info, unsigned char ftype, uint8_t test)
     fs->journ_inum = 0;
 
     if (verbose) {
-	fprintf(logfp,
+	fprintf(stderr,
 		"ssize: %" PRIu16 " csize: %d serial: %" PRIx64 "\n",
 		getu16(fs, ntfs->fs->ssize), ntfs->fs->csize,
 		getu64(fs, ntfs->fs->serial));
-	fprintf(logfp,
+	fprintf(stderr,
 		"mft_rsize: %d idx_rsize: %d vol: %d mft: %" PRIu64
 		" mft_mir: %" PRIu64 "\n", ntfs->mft_rsize_b,
 		ntfs->idx_rsize_b, (int) fs->block_count, getu64(fs,
