@@ -1,7 +1,7 @@
 /*
 ** The Sleuth Kit
 **
-** $Date: 2005/07/08 17:20:10 $
+** $Date: 2005/09/02 19:53:28 $
 **
 ** Brian Carrier [carrier@sleuthkit.org]
 ** Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
@@ -13,13 +13,16 @@
 #ifndef _NTFS_H
 #define _NTFS_H
 
-
+#ifdef __cplusplus
+extern "C" {
+#endif
 
 //#define NTFS_FS_MAGIC 0x5346544E      /* "NTFS" in little endian */
 #define NTFS_FS_MAGIC	0xAA55
 #define NTFS_DEV_BSIZE	512
 
-#define NTFS_MAXNAMLEN	255
+#define NTFS_MAXNAMLEN	256
+#define NTFS_MAXNAMLEN_UTF8	4 * NTFS_MAXNAMLEN
 
 /* location of the Root Directory inode */
 #define NTFS_ROOTINO	NTFS_MFT_ROOT
@@ -34,10 +37,10 @@
  * Update sequence structure.  This is located at upd_off from the
  * begining of the original structure
  */
-typedef struct {
-    uint8_t upd_val[2];		// what they should be 
-    uint8_t upd_seq;		// array of size 2*(upd_cnt-1) w/orig vals
-} ntfs_upd;
+    typedef struct {
+	uint8_t upd_val[2];	// what they should be 
+	uint8_t upd_seq;	// array of size 2*(upd_cnt-1) w/orig vals
+    } ntfs_upd;
 
 
 /************************************************************************
@@ -45,23 +48,23 @@ typedef struct {
  *
  * located in sector 0 in $Boot
  */
-typedef struct {
-    uint8_t f1[3];		// 0
-    char oemname[8];		// 3
-    uint8_t ssize[2];		// 11   /* sector size in bytes */
-    uint8_t csize;		// 13  /* sectors per cluster */
-    uint8_t f2[26];		// 14
-    uint8_t vol_size_s[8];	// 40   /*size of volume in sectors */
-    uint8_t mft_clust[8];	// 48   /* location of MFT */
-    uint8_t mftm_clust[8];	// 56    /* location of MFT mirror */
-    int8_t mft_rsize_c;		// 64      /* number of clusters per mft record */
-    uint8_t f3[3];
-    int8_t idx_rsize_c;		// 68      /* number of clus per idx rec */
-    uint8_t f4[3];
-    uint8_t serial[8];		// 72   /* serial number */
-    uint8_t f5[430];		//80
-    uint8_t magic[2];
-} ntfs_sb;
+    typedef struct {
+	uint8_t f1[3];		// 0
+	char oemname[8];	// 3
+	uint8_t ssize[2];	// 11   /* sector size in bytes */
+	uint8_t csize;		// 13  /* sectors per cluster */
+	uint8_t f2[26];		// 14
+	uint8_t vol_size_s[8];	// 40   /*size of volume in sectors */
+	uint8_t mft_clust[8];	// 48   /* location of MFT */
+	uint8_t mftm_clust[8];	// 56    /* location of MFT mirror */
+	int8_t mft_rsize_c;	// 64      /* number of clusters per mft record */
+	uint8_t f3[3];
+	int8_t idx_rsize_c;	// 68      /* number of clus per idx rec */
+	uint8_t f4[3];
+	uint8_t serial[8];	// 72   /* serial number */
+	uint8_t f5[430];	//80
+	uint8_t magic[2];
+    } ntfs_sb;
 
 
 
@@ -70,23 +73,23 @@ typedef struct {
  *
  * One entry in the MFT - there exists one for each file
  */
-typedef struct {
-    uint8_t magic[4];
-    uint8_t upd_off[2];		// 4
-    uint8_t upd_cnt[2];		// 6  size+1
-    uint8_t lsn[8];		// 8  $LogFile Sequence Number
-    uint8_t seq[2];		// 16
-    uint8_t link[2];		// 18
-    uint8_t attr_off[2];	// 20
-    uint8_t flags[2];		// 22
-    uint8_t size[4];		// 24
-    uint8_t alloc_size[4];	//28
-    uint8_t base_ref[6];	// 32 
-    uint8_t base_seq[2];	// 38 
-    uint8_t next_attrid[2];	// 40 The next id to be assigned
-    uint8_t f1[2];		// XP Only
-    uint8_t entry[4];		// XP Only - Number of this entry
-} ntfs_mft;
+    typedef struct {
+	uint8_t magic[4];
+	uint8_t upd_off[2];	// 4
+	uint8_t upd_cnt[2];	// 6  size+1
+	uint8_t lsn[8];		// 8  $LogFile Sequence Number
+	uint8_t seq[2];		// 16
+	uint8_t link[2];	// 18
+	uint8_t attr_off[2];	// 20
+	uint8_t flags[2];	// 22
+	uint8_t size[4];	// 24
+	uint8_t alloc_size[4];	//28
+	uint8_t base_ref[6];	// 32 
+	uint8_t base_seq[2];	// 38 
+	uint8_t next_attrid[2];	// 40 The next id to be assigned
+	uint8_t f1[2];		// XP Only
+	uint8_t entry[4];	// XP Only - Number of this entry
+    } ntfs_mft;
 
 /* Magic values for each MFT entry */
 #define NTFS_MFT_MAGIC	0x454c4946
@@ -120,35 +123,35 @@ typedef struct {
 /************************************************************************
  * Attribute Header for resident and non-resident attributes
  */
-typedef struct {
-    uint8_t type[4];
-    uint8_t len[4];		// 4 - length including header
-    uint8_t res;		// 8 - resident flag
-    uint8_t nlen;		// 9 - name length
-    uint8_t name_off[2];	// 10 - offset to name 
-    uint8_t flags[2];		// 12  
-    uint8_t id[2];		// 14 - unique identifier
+    typedef struct {
+	uint8_t type[4];
+	uint8_t len[4];		// 4 - length including header
+	uint8_t res;		// 8 - resident flag
+	uint8_t nlen;		// 9 - name length
+	uint8_t name_off[2];	// 10 - offset to name 
+	uint8_t flags[2];	// 12  
+	uint8_t id[2];		// 14 - unique identifier
 
-    union {
-	/* Resident Values */
-	struct {
-	    uint8_t ssize[4];	// 16 - size of content
-	    uint8_t soff[2];	// 20 - offset to content (after name)
-	    uint8_t idxflag[2];	// 22 - indexed flag 
-	} r;
-	/* Non-resident Values */
-	struct {
-	    uint8_t start_vcn[8];	// 16 - starting VCN of this attribute
-	    uint8_t last_vcn[8];	// 24
-	    uint8_t run_off[2];	// 32 - offset to the data runs (after name)
-	    uint8_t compusize[2];	// 34 - compression unit size (2^x)
-	    uint8_t f1[4];	// 36
-	    uint8_t alen[8];	// 40   allocated size of stream
-	    uint8_t ssize[8];	// 48   actual size of stream
-	    uint8_t initsize[8];	// 56   initialized steam size
-	} nr;
-    } c;
-} ntfs_attr;
+	union {
+	    /* Resident Values */
+	    struct {
+		uint8_t ssize[4];	// 16 - size of content
+		uint8_t soff[2];	// 20 - offset to content (after name)
+		uint8_t idxflag[2];	// 22 - indexed flag 
+	    } r;
+	    /* Non-resident Values */
+	    struct {
+		uint8_t start_vcn[8];	// 16 - starting VCN of this attribute
+		uint8_t last_vcn[8];	// 24
+		uint8_t run_off[2];	// 32 - offset to the data runs (after name)
+		uint8_t compusize[2];	// 34 - compression unit size (2^x)
+		uint8_t f1[4];	// 36
+		uint8_t alen[8];	// 40   allocated size of stream
+		uint8_t ssize[8];	// 48   actual size of stream
+		uint8_t initsize[8];	// 56   initialized steam size
+	    } nr;
+	} c;
+    } ntfs_attr;
 
 /* values for the res field */
 #define NTFS_MFT_RES	0	/* resident */
@@ -189,20 +192,20 @@ typedef struct {
 /************************************************************************
  * File Name Attribute
  */
-typedef struct {
-    uint8_t par_ref[6];		/* file reference to base File Record of parent */
-    uint8_t par_seq[2];		/* seq num to base File Record of parent */
-    uint8_t crtime[8];		/* file creation */
-    uint8_t mtime[8];		/* file altered */
-    uint8_t ctime[8];		/* mod time for FILE record (MFT Entry) */
-    uint8_t atime[8];		/* access time */
-    uint8_t alloc_fsize[8];
-    uint8_t real_fsize[8];
-    uint8_t flags[8];
-    uint8_t nlen;		/* length of file name */
-    uint8_t nspace;
-    uint8_t name;		/* in unicode */
-} ntfs_attr_fname;
+    typedef struct {
+	uint8_t par_ref[6];	/* file reference to base File Record of parent */
+	uint8_t par_seq[2];	/* seq num to base File Record of parent */
+	uint8_t crtime[8];	/* file creation */
+	uint8_t mtime[8];	/* file altered */
+	uint8_t ctime[8];	/* mod time for FILE record (MFT Entry) */
+	uint8_t atime[8];	/* access time */
+	uint8_t alloc_fsize[8];
+	uint8_t real_fsize[8];
+	uint8_t flags[8];
+	uint8_t nlen;		/* length of file name */
+	uint8_t nspace;
+	uint8_t name;		/* in unicode */
+    } ntfs_attr_fname;
 
 /* values for the flags field of attr_fname */
 #define	NTFS_FNAME_FLAGS_RO		0x0000000000000001
@@ -234,20 +237,20 @@ typedef struct {
 /************************************************************************
  * Standard Information Attribute
  */
-typedef struct {
-    uint8_t crtime[8];		/* creation date */
-    uint8_t mtime[8];		/* file altered */
-    uint8_t ctime[8];		/* MFT Changed */
-    uint8_t atime[8];		/* last access (read) */
-    uint8_t dos[4];		/* permissions in DOS Format */
-    uint8_t maxver[4];
-    uint8_t ver[4];
-    uint8_t class_id[4];
-    uint8_t own_id[4];
-    uint8_t sec_id[4];
-    uint8_t quota[8];
-    uint8_t usn[8];
-} ntfs_attr_si;
+    typedef struct {
+	uint8_t crtime[8];	/* creation date */
+	uint8_t mtime[8];	/* file altered */
+	uint8_t ctime[8];	/* MFT Changed */
+	uint8_t atime[8];	/* last access (read) */
+	uint8_t dos[4];		/* permissions in DOS Format */
+	uint8_t maxver[4];
+	uint8_t ver[4];
+	uint8_t class_id[4];
+	uint8_t own_id[4];
+	uint8_t sec_id[4];
+	uint8_t quota[8];
+	uint8_t usn[8];
+    } ntfs_attr_si;
 
 
 /* DOS Flags values */
@@ -270,13 +273,13 @@ typedef struct {
 /************************************************************************
  * Volume Info Attribute
  */
-typedef struct {
-    uint8_t f1[8];
-    uint8_t maj_ver;
-    uint8_t min_ver;
-    uint8_t flags[2];
-    uint8_t f2[4];
-} ntfs_attr_vinfo;
+    typedef struct {
+	uint8_t f1[8];
+	uint8_t maj_ver;
+	uint8_t min_ver;
+	uint8_t flags[2];
+	uint8_t f2[4];
+    } ntfs_attr_vinfo;
 
 #define NTFS_VINFO_DIRTY	0x0001	// Dirty
 #define NTFS_VINFO_RESLOG	0x0002	// Resize LogFile
@@ -302,17 +305,17 @@ typedef struct {
 /************************************************************************
  * attribute list 
  */
-typedef struct {
-    uint8_t type[4];		// Attribute Type
-    uint8_t len[2];		// length of entry
-    uint8_t nlen;		// number of chars in name
-    uint8_t f1;			// 7
-    uint8_t start_vcn[8];	// starting VCN or NTFS_ATTRL_RES 
-    uint8_t file_ref[6];	// file reference to new MFT entry
-    uint8_t seq[2];		// 22
-    uint8_t id[2];		// id (also in the attribute header)
-    uint8_t name;		// 26  name in unicode
-} ntfs_attrlist;
+    typedef struct {
+	uint8_t type[4];	// Attribute Type
+	uint8_t len[2];		// length of entry
+	uint8_t nlen;		// number of chars in name
+	uint8_t f1;		// 7
+	uint8_t start_vcn[8];	// starting VCN or NTFS_ATTRL_RES 
+	uint8_t file_ref[6];	// file reference to new MFT entry
+	uint8_t seq[2];		// 22
+	uint8_t id[2];		// id (also in the attribute header)
+	uint8_t name;		// 26  name in unicode
+    } ntfs_attrlist;
 
 #define NTFS_ATTRL_RES	0
 
@@ -326,13 +329,13 @@ typedef struct {
  * It is located in the MFT and pointed to by the run_off in the header
  */
 
-typedef struct {
-    /* lsb 4 bits: num of bytes in run length field
-     * msb 4 bits: num of bytes in run offset field - (LCN)
-     */
-    uint8_t len;
-    uint8_t buf[32];
-} ntfs_runlist;
+    typedef struct {
+	/* lsb 4 bits: num of bytes in run length field
+	 * msb 4 bits: num of bytes in run offset field - (LCN)
+	 */
+	uint8_t len;
+	uint8_t buf[32];
+    } ntfs_runlist;
 
 #define NTFS_RUNL_LENSZ(runl)	\
 	(uint8_t)(runl->len & 0x0f)
@@ -353,12 +356,12 @@ typedef struct {
 /*
  * Starting at begin_off is a stream of ntfs_idxentry structures 
  */
-typedef struct {
-    uint8_t begin_off[4];	/* offset to seq of idx entries */
-    uint8_t end_off[4];		/* offset to end of seq of idx entries */
-    uint8_t buf_off[4];		/* offset to end of idx buffer */
-    uint8_t flags[4];
-} ntfs_idxelist;
+    typedef struct {
+	uint8_t begin_off[4];	/* offset to seq of idx entries */
+	uint8_t end_off[4];	/* offset to end of seq of idx entries */
+	uint8_t buf_off[4];	/* offset to end of idx buffer */
+	uint8_t flags[4];
+    } ntfs_idxelist;
 
 /* value for flags */
 #define NTFS_IDXELIST_CHILD	0x1	/* children exist below this node */
@@ -366,14 +369,14 @@ typedef struct {
 
 
 /* This is general index information and applies to $IDX_ALLOC as well */
-typedef struct {
-    uint8_t type[4];		/* ATYPE that tree is sorted by */
-    uint8_t collation_rule[4];
-    uint8_t idxalloc_size_b[4];	/* index alloc size in bytes */
-    uint8_t idx_size_c;		/* index alloc size in clusters */
-    uint8_t pad[3];
-    ntfs_idxelist list;
-} ntfs_idxroot;
+    typedef struct {
+	uint8_t type[4];	/* ATYPE that tree is sorted by */
+	uint8_t collation_rule[4];
+	uint8_t idxalloc_size_b[4];	/* index alloc size in bytes */
+	uint8_t idx_size_c;	/* index alloc size in clusters */
+	uint8_t pad[3];
+	ntfs_idxelist list;
+    } ntfs_idxroot;
 
 
 
@@ -387,14 +390,14 @@ typedef struct {
  */
 
 
-typedef struct {
-    uint8_t magic[4];		/* INDX */
-    uint8_t upd_off[2];
-    uint8_t upd_cnt[2];		/* size + 1 */
-    uint8_t lsn[8];		/*  $LogFile Sequence Number */
-    uint8_t idx_vcn[8];		/* vcn in idx alloc attr */
-    ntfs_idxelist list;
-} ntfs_idxrec;
+    typedef struct {
+	uint8_t magic[4];	/* INDX */
+	uint8_t upd_off[2];
+	uint8_t upd_cnt[2];	/* size + 1 */
+	uint8_t lsn[8];		/*  $LogFile Sequence Number */
+	uint8_t idx_vcn[8];	/* vcn in idx alloc attr */
+	ntfs_idxelist list;
+    } ntfs_idxrec;
 
 
 #define NTFS_IDXREC_MAGIC	0x58444e49	/* INDX */
@@ -403,18 +406,18 @@ typedef struct {
 
 /************************************************************************
  * This structure exists for each file and directory in the tree */
-typedef struct {
-    uint8_t file_ref[6];	/* file reference (invalid for last entry) */
-    uint8_t seq_num[2];		/* file reference (invalid for last entry) */
-    uint8_t idxlen[2];		/* length of the index entry */
-    uint8_t strlen[2];		/* length of stream */
-    uint8_t flags;
-    uint8_t f1[3];
-    uint8_t stream;		/* length of strlen - invalid for last entry */
-    /* loc of subnode is found in last 8-bytes
-     * of idx entry (idxlen - 8).  use macro 
-     */
-} ntfs_idxentry;
+    typedef struct {
+	uint8_t file_ref[6];	/* file reference (invalid for last entry) */
+	uint8_t seq_num[2];	/* file reference (invalid for last entry) */
+	uint8_t idxlen[2];	/* length of the index entry */
+	uint8_t strlen[2];	/* length of stream */
+	uint8_t flags;
+	uint8_t f1[3];
+	uint8_t stream;		/* length of strlen - invalid for last entry */
+	/* loc of subnode is found in last 8-bytes
+	 * of idx entry (idxlen - 8).  use macro 
+	 */
+    } ntfs_idxentry;
 
 #define NTFS_IDX_SUB	0x01	/* Entry points to a sub-node */
 #define NTFS_IDX_LAST	0x02	/* last indx entry in the node */
@@ -430,15 +433,15 @@ typedef struct {
 /************************************************************************
 */
 
-typedef struct {
-    char label[128];		/* label in unicode */
-    uint8_t type[4];
-    uint8_t disp[4];		/* display rule */
-    uint8_t coll[4];		/* collation rule */
-    uint8_t flags[4];
-    uint8_t minsize[8];		/* minimum size */
-    uint8_t maxsize[8];		/* maximum size */
-} ntfs_attrdef;
+    typedef struct {
+	char label[128];	/* label in unicode */
+	uint8_t type[4];
+	uint8_t disp[4];	/* display rule */
+	uint8_t coll[4];	/* collation rule */
+	uint8_t flags[4];
+	uint8_t minsize[8];	/* minimum size */
+	uint8_t maxsize[8];	/* maximum size */
+    } ntfs_attrdef;
 
 #define NTFS_ATTRDEF_FLAGS_IDX	0x02
 #define NTFS_ATTRDEF_FLAGS_RES	0x40	/* always resident */
@@ -450,52 +453,56 @@ typedef struct {
  * OBJECT_ID attribute
 */
 
-typedef struct {
-    uint8_t objid1[8];		/* object id of file or directory */
-    uint8_t objid2[8];
-    uint8_t orig_volid1[8];	/* id of "birth" volume */
-    uint8_t orig_volid2[8];
-    uint8_t orig_objid1[8];	/* original object id */
-    uint8_t orig_objid2[8];
-    uint8_t orig_domid1[8];	/* id of "birth" domain */
-    uint8_t orig_domid2[8];
-} ntfs_attr_objid;
+    typedef struct {
+	uint8_t objid1[8];	/* object id of file or directory */
+	uint8_t objid2[8];
+	uint8_t orig_volid1[8];	/* id of "birth" volume */
+	uint8_t orig_volid2[8];
+	uint8_t orig_objid1[8];	/* original object id */
+	uint8_t orig_objid2[8];
+	uint8_t orig_domid1[8];	/* id of "birth" domain */
+	uint8_t orig_domid2[8];
+    } ntfs_attr_objid;
 
 
 /************************************************************************
 */
-typedef struct {
-    FS_INFO fs_info;		/* super class */
-    ntfs_sb *fs;
-    uint8_t ver;		/* version of NTFS - uses the VINFO flag */
-    FS_INODE *mft_inode;	/* contains the data for the mft entry for the mft */
-    FS_DATA *mft_data;		/* Data run for MFT entry for MFT */
-    ntfs_mft *mft;		/* cache for on-disk inode */
-    INUM_T mnum;		/* number of above cached mft */
-    uint16_t csize_b;		/* number of bytes in a cluster */
-    uint16_t ssize_b;		/* number of bytes in a sector */
-    uint16_t mft_rsize_b;	/* number of bytes per mft record */
-    uint16_t idx_rsize_b;	/* number of bytes per idx record */
-    DADDR_T root_mft_addr;	/* address of first mft entry */
+    typedef struct {
+	FS_INFO fs_info;	/* super class */
+	ntfs_sb *fs;
+	uint8_t ver;		/* version of NTFS - uses the VINFO flag */
+	FS_INODE *mft_inode;	/* contains the data for the mft entry for the mft */
+	FS_DATA *mft_data;	/* Data run for MFT entry for MFT */
+	ntfs_mft *mft;		/* cache for on-disk inode */
+	INUM_T mnum;		/* number of above cached mft */
+	uint16_t csize_b;	/* number of bytes in a cluster */
+	uint16_t ssize_b;	/* number of bytes in a sector */
+	uint16_t mft_rsize_b;	/* number of bytes per mft record */
+	uint16_t idx_rsize_b;	/* number of bytes per idx record */
+	DADDR_T root_mft_addr;	/* address of first mft entry */
 
-    uint8_t loading_the_MFT;	/* set to 1 when initializing the setup */
+	uint8_t loading_the_MFT;	/* set to 1 when initializing the setup */
 
-    FS_DATA_RUN *bmap;		/* Run of bitmap for clusters (linked list) */
-    DATA_BUF *bmap_buf;		/* buffer to hold cached copy of bitmap */
-    DADDR_T bmap_buf_off;	/* offset cluster in cached bitmap */
-    ntfs_attrdef *attrdef;
+	FS_DATA_RUN *bmap;	/* Run of bitmap for clusters (linked list) */
+	DATA_BUF *bmap_buf;	/* buffer to hold cached copy of bitmap */
+	DADDR_T bmap_buf_off;	/* offset cluster in cached bitmap */
+	ntfs_attrdef *attrdef;
 
-} NTFS_INFO;
+    } NTFS_INFO;
 
-extern void
- ntfs_data_walk(NTFS_INFO *, INUM_T, FS_DATA *, int, FS_FILE_WALK_FN, void *);
+    extern void
+     ntfs_data_walk(NTFS_INFO *, INUM_T, FS_DATA *, int, FS_FILE_WALK_FN,
+		    void *);
 
-extern void
- ntfs_dent_walk(FS_INFO *, INUM_T, int, FS_DENT_WALK_FN, void *);
+    extern void
+     ntfs_dent_walk(FS_INFO *, INUM_T, int, FS_DENT_WALK_FN, void *);
 
-extern uint32_t nt2unixtime(uint64_t ntdate);
+    extern uint32_t nt2unixtime(uint64_t ntdate);
 
-extern void
- ntfs_attrname_lookup(FS_INFO *, uint16_t, char *, int);
+    extern void
+     ntfs_attrname_lookup(FS_INFO *, uint16_t, char *, int);
 
+#ifdef __cplusplus
+}
+#endif
 #endif
