@@ -2,7 +2,7 @@
 ** ntfs_dent
 ** The Sleuth Kit
 **
-** $Date: 2005/06/15 15:58:03 $
+** $Date: 2005/10/13 04:15:22 $
 **
 ** name layer support for the NTFS file system
 **
@@ -12,11 +12,16 @@
 ** TASK
 ** Copyright (c) 2002 Brian Carrier, @stake Inc.  All rights reserved
 **
+**
+** This software is distributed under the Common Public License 1.0
+**
+** Unicode added with support from I.D.E.A.L. Technology Corp (Aug '05)
+**
 */
 #include "fs_tools.h"
 #include "fs_data.h"
 #include "ntfs.h"
-
+#include "fs_unicode.h"
 
 
 #define MAX_DEPTH   64
@@ -51,13 +56,32 @@ ntfs_dent_copy(NTFS_INFO * ntfs, NTFS_DINFO * dinfo, ntfs_idxentry * idxe,
 {
     ntfs_attr_fname *fname = (ntfs_attr_fname *) & idxe->stream;
     FS_INFO *fs = (FS_INFO *) & ntfs->fs_info;
+    UTF16 *name16;
+    UTF8 *name8;
+    int retVal;
 
     fs_dent->inode = getu48(fs, idxe->file_ref);
 
-    /* Copy the name */
-    fs_dent->namlen = fname->nlen;
-    uni2ascii((char *) &fname->name, fname->nlen,
-	      fs_dent->name, fs_dent->maxnamlen);
+    name16 = (UTF16 *) & fname->name;
+    name8 = (UTF8 *) fs_dent->name;
+
+    retVal = fs_UTF16toUTF8(fs, (const UTF16 **) &name16,
+			    (UTF16 *) ((uintptr_t) name16 +
+				       fname->nlen * 2), &name8,
+			    (UTF8 *) ((uintptr_t) name8 +
+				      fs_dent->name_max),
+			    lenientConversion);
+
+    if (retVal != conversionOK) {
+	error("Error converting NTFS name to UTF8: %d %d", retVal,
+	      fs_dent->inode);
+    }
+
+    /* Make sure it is NULL Terminated */
+    if ((uintptr_t) name8 > (uintptr_t) fs_dent->name + fs_dent->name_max)
+	fs_dent->name[fs_dent->name_max] = '\0';
+    else
+	*name8 = '\0';
 
     /* copy the path data */
     fs_dent->path = dinfo->dirs;
@@ -122,11 +146,11 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 {
     uintptr_t endaddr, endaddr_alloc;
     int myflags = 0;
-    FS_DENT *fs_dent = fs_dent_alloc(NTFS_MAXNAMLEN);
+    FS_DENT *fs_dent = fs_dent_alloc(NTFS_MAXNAMLEN_UTF8, 0);
     FS_INFO *fs = (FS_INFO *) & ntfs->fs_info;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"ntfs_dent_idxentry: Processing entry: %" PRIu64
 		"  Size: %" PRIu32 "  Len: %" PRIu32 "\n",
 		(uint64_t) ((uintptr_t) idxe), size, len);
@@ -145,7 +169,7 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_dent_idxentry: New IdxEnt: %" PRIu64
 		    " $FILE_NAME Entry: %" PRIu64 "  File Ref: %" PRIu64
 		    "  IdxEnt Len: %" PRIu16 "  StrLen: %" PRIu16 "\n",
@@ -196,7 +220,6 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 
 		idxe = (ntfs_idxentry *) ((uintptr_t) idxe + 4);
 		continue;
-
 	    }
 	}
 
@@ -210,23 +233,25 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	 *
 	 * Note that we could be missing some info from deleted files
 	 * if the windows version was deleted and the DOS wasn't...
+	 *
+	 * @@@ This should be added to the shrt_name entry of FS_DENT.  The short
+	 * name entry typically comes after the long name
 	 */
 
 	if (fname->nspace == NTFS_FNAME_DOS) {
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"ntfs_dent_idxentry: Skipping because of name space: %d\n",
 			fname->nspace);
 
 	    goto incr_entry;
 	}
 
-
 	/* Copy it into the generic form */
 	ntfs_dent_copy(ntfs, dinfo, idxe, fs_dent);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_dent_idxentry: Deletion Check Details of %s: Str Len: %"
 		    PRIu16 "  Len to end after current: %" PRIu64 "\n",
 		    fs_dent->name, getu16(fs, idxe->strlen),
@@ -253,8 +278,9 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	    }
 	    myflags = FS_FLAG_NAME_UNALLOC;
 	}
-	else
+	else {
 	    myflags = FS_FLAG_NAME_ALLOC;
+	}
 
 
 	if ((flags & myflags) == myflags) {
@@ -301,22 +327,23 @@ ntfs_dent_idxentry(NTFS_INFO * ntfs, NTFS_DINFO * dinfo,
 	 * 66: size of fname before name
 	 * 2*nlen: size of name (in unicode)
 	 */
-	if (getu16(fs, idxe->strlen) == 0)
+	if (getu16(fs, idxe->strlen) == 0) {
 	    idxe =
 		(ntfs_idxentry
 		 *) ((((uintptr_t) idxe + 16 + 66 + 2 * fname->nlen +
 		       3) / 4) * 4);
-	else
+	}
+	else {
 	    idxe =
 		(ntfs_idxentry *) ((uintptr_t) idxe +
 				   getu16(fs, idxe->idxlen));
+	}
 
     }				/* end of loop of index entries */
 
     fs_dent_free(fs_dent);
 
     return WALK_CONT;
-
 }
 
 
@@ -336,7 +363,7 @@ ntfs_fix_idxrec(NTFS_INFO * ntfs, ntfs_idxrec * idxrec, uint32_t len)
     ntfs_upd *upd;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"ntfs_fix_idxrec: Fixing idxrec: %" PRIu64 "  Len: %"
 		PRIu32 "\n", (uint64_t) ((uintptr_t) idxrec), len);
 
@@ -377,7 +404,7 @@ ntfs_fix_idxrec(NTFS_INFO * ntfs, ntfs_idxrec * idxrec, uint32_t len)
 	old_val = (uint8_t *) ((uintptr_t) idxrec + offset);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_fix_idxrec: upd_seq %i   Replacing: %.4" PRIx16
 		    "   With: %.4" PRIx16 "\n", i, getu16(fs, old_val),
 		    getu16(fs, new_val));
@@ -430,7 +457,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	error("invalid inode value: %" PRIuINUM "\n", inum);
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"ntfs_dent_walk: Processing directory %" PRIuINUM "\n",
 		inum);
 
@@ -448,18 +475,17 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
      * a '.' and '..' entry and call the action
      */
     if ((inum != fs->root_inum) && (flags & FS_FLAG_NAME_ALLOC)) {
-	FS_DENT *fs_dent = fs_dent_alloc(16);
+	FS_DENT *fs_dent = fs_dent_alloc(16, 0);
 	FS_NAME *fs_name;
 	int myflags = FS_FLAG_NAME_ALLOC;
 
 	if (verbose)
-	    fprintf(logfp, "ntfs_dent_walk: Creating . and .. entries\n");
+	    fprintf(stderr, "ntfs_dent_walk: Creating . and .. entries\n");
 
 	/* 
 	 * "." 
 	 */
 	fs_dent->inode = inum;
-	fs_dent->namlen = 1;
 	strcpy(fs_dent->name, ".");
 
 	/* copy the path data */
@@ -483,7 +509,6 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	/*
 	 * ".."
 	 */
-	fs_dent->namlen = 2;
 	strcpy(fs_dent->name, "..");
 	fs_dent->ent_type = FS_DENT_DIR;
 
@@ -569,6 +594,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	    error
 		("Error: $IDX_ROOT says there should be children, but there isn't");
 
+	fs_inode_free(fs_inode);
 	return;
     }
 
@@ -588,17 +614,24 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
     load_file.cur = load_file.base = idxalloc;
 
     if (verbose)
-	fprintf(logfp, "ntfs_dent_walk: Copying $IDX_ALLOC into buffer\n");
+	fprintf(stderr,
+		"ntfs_dent_walk: Copying $IDX_ALLOC into buffer\n");
 
     ntfs_data_walk(ntfs, fs_inode->addr, fs_data_alloc,
-		   FS_FLAG_FILE_SLACK, load_file_action,
-		   (void *) &load_file);
+		   FS_FLAG_FILE_SLACK | FS_FLAG_FILE_NOABORT,
+		   load_file_action, (void *) &load_file);
 
-    if (load_file.left > 0)
-	error
-	    ("ntfs_dent_walk: Buffer not filled when copying $IDX_ALLOC (%Zd)",
-	     load_file.left);
+    /* Not all of the directory was copied, so we exit */
+    if (load_file.left > 0) {
+	free(idxalloc);
+	fs_inode_free(fs_inode);
 
+	if (dinfo->depth == 0)
+	    error("Error reading directory contents: %" PRIuINUM "\n",
+		  inum);
+
+	return;
+    }
 
     /*
      * The idxalloc is a big buffer that contains one or more
@@ -623,7 +656,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	idxrec = (ntfs_idxrec *) & idxalloc[off];
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_dent_walk: Index Buffer Offset: %d  Magic: %"
 		    PRIx32 "\n", off, getu32(fs, idxrec->magic));
 
@@ -647,7 +680,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	rec_len = ((uintptr_t) idxrec - (uintptr_t) idxrec_p);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_dent_walk: Processing previous index record (len: %"
 		    PRIu32 ")\n", rec_len);
 
@@ -693,7 +726,7 @@ ntfs_dent_walk_lcl(FS_INFO * fs, NTFS_DINFO * dinfo, INUM_T inum,
 	    idxalloc_len - ((uintptr_t) idxrec_p - (uintptr_t) idxalloc);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "ntfs_dent_walk: Processing final index record (len: %"
 		    PRIu32 ")\n", rec_len);
 
@@ -868,7 +901,7 @@ ntfs_find_file(FS_INFO * fs, INUM_T inode_toid, uint32_t type_toid,
 
     FS_INODE *fs_inode;
     FS_NAME *fs_name;
-    FS_DENT *fs_dent = fs_dent_alloc(NTFS_MAXNAMLEN);
+    FS_DENT *fs_dent = fs_dent_alloc(NTFS_MAXNAMLEN_UTF8, 0);
     int myflags;
     NTFS_INFO *ntfs = (NTFS_INFO *) fs;
     char *attr = NULL;
@@ -914,20 +947,18 @@ ntfs_find_file(FS_INFO * fs, INUM_T inode_toid, uint32_t type_toid,
 	    attr = fs_data->name;
     }
 
-
     /* loop through all the names it may have */
     for (fs_name = fs_inode->name; fs_name != NULL;
 	 fs_name = fs_name->next) {
 
 	/* Append on the attribute name, if it exists */
 	if (attr != NULL) {
-	    snprintf(fs_dent->name, fs_dent->maxnamlen, "%s:%s",
+	    snprintf(fs_dent->name, fs_dent->name_max, "%s:%s",
 		     fs_name->name, attr);
 	}
 	else {
-	    strncpy(fs_dent->name, fs_name->name, fs_dent->maxnamlen);
+	    strncpy(fs_dent->name, fs_name->name, fs_dent->name_max);
 	}
-	fs_dent->namlen = strlen(fs_dent->name);
 
 	/* if this is in the root directory, then call back */
 	if (fs_name->par_inode == NTFS_ROOTINO) {
