@@ -23,6 +23,8 @@ These notices must be retained in any copies of any part of this
 documentation and/or software.
  */
 
+#include "tsk_os.h"
+#include "tsk_types.h"
 #include "global.h"
 #include "hash.h"
 
