@@ -31,6 +31,8 @@ effort (for example the reengineering of a great many Capstone chips).
 
 #include <stdio.h>
 #include <string.h>
+#include "tsk_os.h"
+#include "tsk_types.h"
 #include "global.h"
 #include "hash.h"
 
