@@ -1,38 +1,14 @@
 /*
- * $Date: 2005/06/13 19:27:22 $
+ * $Date: 2005/09/02 23:34:04 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2005 Brian Carrier.  All rights reserved
  *
  * split
  *
- * This file is part of imgtools
  *
- * imgtools is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version.
+ * This software is distributed under the Common Public License 1.0
  *
- * imgtools is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with mactime; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
- * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
- * MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
- *
- * IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR
- * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include <sys/types.h>
@@ -48,7 +24,7 @@ split_read_random(IMG_INFO * img_info, char *buf, OFF_T len, OFF_T offset)
     int i;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"split_read_random: byte offset: %" PRIuOFF " len: %"
 		PRIuOFF "\n", offset, len);
 
@@ -81,7 +57,7 @@ split_read_random(IMG_INFO * img_info, char *buf, OFF_T len, OFF_T offset)
 
 
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"split_read_rand: found in image %d relative: %"
 			PRIuOFF "  len: %" PRIuOFF "\n", i, rel_offset,
 			read_len);
@@ -89,7 +65,7 @@ split_read_random(IMG_INFO * img_info, char *buf, OFF_T len, OFF_T offset)
 	    /* Is the image already open? */
 	    if (split_info->cptr[i] == -1) {
 		if (verbose)
-		    fprintf(logfp,
+		    fprintf(stderr,
 			    "split_read_rand: opening file into slot %d %s\n",
 			    split_info->next_slot, split_info->images[i]);
 
@@ -99,7 +75,7 @@ split_read_random(IMG_INFO * img_info, char *buf, OFF_T len, OFF_T offset)
 		/* Free it if being used */
 		if (cimg->fd != 0) {
 		    if (verbose)
-			fprintf(logfp,
+			fprintf(stderr,
 				"split_read_rand: closing file %s\n",
 				split_info->images[cimg->image]);
 		    close(cimg->fd);
@@ -151,14 +127,14 @@ split_read_random(IMG_INFO * img_info, char *buf, OFF_T len, OFF_T offset)
 			    split_info->max_off[i - 1];
 
 		    if (verbose)
-			fprintf(logfp,
+			fprintf(stderr,
 				"split_read_rand: Additional image reads: image %d  len: %"
 				PRIuOFF "\n", i, read_len);
 
 		    /* Is the image already open? */
 		    if (split_info->cptr[i] == -1) {
 			if (verbose)
-			    fprintf(logfp,
+			    fprintf(stderr,
 				    "split_read_rand: opening file into slot %d %s\n",
 				    split_info->next_slot,
 				    split_info->images[i]);
@@ -169,7 +145,7 @@ split_read_random(IMG_INFO * img_info, char *buf, OFF_T len, OFF_T offset)
 			/* Free it if being used */
 			if (cimg->fd != 0) {
 			    if (verbose)
-				fprintf(logfp,
+				fprintf(stderr,
 					"split_read_rand: closing file %s\n",
 					split_info->images[cimg->image]);
 			    close(cimg->fd);
@@ -317,7 +293,7 @@ split_open(OFF_T offset, int num_img, const char **images, IMG_INFO * next)
 	split_info->max_off[i] = img_info->size;
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "split_open: %d  size: %" PRIuOFF "  max offset: %"
 		    PRIuOFF "  Name: %s\n", i, sb.st_size,
 		    split_info->max_off[i], images[i]);
