@@ -1,40 +1,16 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/01/17 22:40:17 $
+ * $Date: 2005/09/02 23:34:04 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
  *
  * bsd.c: BSD Disk labels
  *
- * This file is part of mmtools
  *
- * mmtools is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version.
+ * This software is distributed under the Common Public License 1.0
  *
- * mmtools is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with mactime; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
- * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
- * MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
- *
- * IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR
- * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include "mm_tools.h"
@@ -115,7 +91,7 @@ bsd_load_table(MM_INFO * mm, uint8_t test)
     uint32_t idx = 0;
 
     if (verbose)
-	fprintf(logfp, "bsd_load_table: Table Sector: %" PRIuDADDR "\n",
+	fprintf(stderr, "bsd_load_table: Table Sector: %" PRIuDADDR "\n",
 		mm->sect_offset);
 
     /* seek to the table */
@@ -193,7 +169,7 @@ bsd_load_table(MM_INFO * mm, uint8_t test)
 	part_size = getu32(mm, dlabel.part[idx].size_sec);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "load_table: %d  Starting Sector: %" PRIu32
 		    "  Size: %" PRIu32 "  Type: %d\n", idx, part_start,
 		    part_size, dlabel.part[idx].fstype);
