@@ -1,40 +1,16 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/04/01 18:56:49 $
+ * $Date: 2005/09/02 23:34:04 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
  *
  * DOS Partition Tables
  *
- * This file is part of mmtools
  *
- * mmtools is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version.
+ * This software is distributed under the Common Public License 1.0
  *
- * mmtools is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with mactime; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
- * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
- * MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
- *
- * IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR
- * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include "mm_tools.h"
@@ -699,7 +675,7 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
     char *table_str;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"dos_load_ext: Table Sector: %" PRIuDADDR
 		", Primary Base Sector: %" PRIuDADDR "\n", sect_cur,
 		sect_ext_base);
@@ -749,7 +725,7 @@ dos_load_ext_table(MM_INFO * mm, DADDR_T sect_cur, DADDR_T sect_ext_base,
 	uint32_t part_size = getu32(mm, part->size_sec);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "load_ext: %d:%d    Start: %" PRIu32 "   Size: %"
 		    PRIu32 "  Type: %d\n", table, i, part_start, part_size,
 		    part->ptype);
@@ -810,7 +786,7 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
     char *table_str;
 
     if (verbose)
-	fprintf(logfp,
+	fprintf(stderr,
 		"dos_load_prim: Table Sector: %" PRIuDADDR "\n",
 		mm->sect_offset);
 
@@ -848,24 +824,24 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
     if (test) {
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "dos_load_prim_table: Testing FAT/NTFS conditions\n");
 
 	if (strncmp("MSDOS", sect.oemname, 5) == 0) {
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"dos_load_prim_table: Test fail - MSDOS OEM name\n");
 	    return 1;
 	}
 	else if (strncmp("MSWIN", sect.oemname, 5) == 0) {
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"dos_load_prim_table: Test fail - MSWIN OEM name\n");
 	    return 1;
 	}
 	else if (strncmp("NTFS", sect.oemname, 4) == 0) {
 	    if (verbose)
-		fprintf(logfp,
+		fprintf(stderr,
 			"dos_load_prim_table: Test fail - NTFS OEM name\n");
 	    return 1;
 	}
@@ -886,7 +862,7 @@ dos_load_prim_table(MM_INFO * mm, uint8_t test)
 	uint32_t part_size = getu32(mm, part->size_sec);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "load_pri:0:%d    Start: %" PRIu32 "   Size: %" PRIu32
 		    "  Type: %d\n", i, part_start, part_size, part->ptype);
 
