@@ -1,40 +1,16 @@
 /*
  * The Sleuth Kit
  *
- * $Date: 2005/06/13 19:27:26 $
+ * $Date: 2005/09/02 23:34:04 $
  *
  * Brian Carrier [carrier@sleuthkit.org]
  * Copyright (c) 2003-2005 Brian Carrier.  All rights reserved
  *
  * SUN - Sun VTOC code
  *
- * This file is part of mmtools
  *
- * mmtools is free software; you can redistribute it and/or modify it
- * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version.
+ * This software is distributed under the Common Public License 1.0
  *
- * mmtools is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
- * for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with mactime; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
- *
- * THIS SOFTWARE IS PROVIDED ``AS IS'' AND WITHOUT ANY EXPRESS OR IMPLIED
- * WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF
- * MERCHANTABILITY AND FITNESS FOR ANY PARTICULAR PURPOSE.
- *
- * IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT,
- * INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
- * (INCLUDING, BUT NOT LIMITED TO, LOSS OF USE, DATA, OR PROFITS OR
- * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
- * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
- * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
- * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  */
 
 #include "mm_tools.h"
@@ -103,14 +79,14 @@ sun_load_table_i386(MM_INFO * mm, sun_dlabel_i386 * dlabel_x86,
     uint32_t idx = 0;
 
     if (verbose)
-	fprintf(logfp, "load_table_i386: Number of partitions: %d\n",
+	fprintf(stderr, "load_table_i386: Number of partitions: %d\n",
 		getu16(mm, dlabel_x86->num_parts));
 
     /* Cycle through the partitions, there are either 8 or 16 */
     for (idx = 0; idx < getu16(mm, dlabel_x86->num_parts); idx++) {
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "load_table_i386: %d  Starting Sector: %lu  Size: %lu  Type: %d\n",
 		    idx,
 		    (ULONG) getu32(mm, dlabel_x86->part[idx].start_sec),
@@ -148,7 +124,7 @@ sun_load_table_sparc(MM_INFO * mm, sun_dlabel_sparc * dlabel_sp,
 	getu16(mm, dlabel_sp->num_head);
 
     if (verbose)
-	fprintf(logfp, "load_table_sparc: Number of partitions: %d\n",
+	fprintf(stderr, "load_table_sparc: Number of partitions: %d\n",
 		getu16(mm, dlabel_sp->num_parts));
 
     /* Cycle through the partitions, there are either 8 or 16 */
@@ -160,7 +136,7 @@ sun_load_table_sparc(MM_INFO * mm, sun_dlabel_sparc * dlabel_sp,
 				    dlabel_sp->part_layout[idx].size_blk);
 
 	if (verbose)
-	    fprintf(logfp,
+	    fprintf(stderr,
 		    "load_table_sparc: %d  Starting Sector: %lu  Size: %lu  Type: %d\n",
 		    idx,
 		    (ULONG) part_start,
@@ -206,7 +182,7 @@ sun_load_table(MM_INFO * mm, uint8_t test)
     }
 
     if (verbose)
-	fprintf(logfp, "sun_load_table: Trying sector: %" PRIuDADDR "\n",
+	fprintf(stderr, "sun_load_table: Trying sector: %" PRIuDADDR "\n",
 		mm->sect_offset);
 
     /* Try the given offset */
@@ -250,7 +226,7 @@ sun_load_table(MM_INFO * mm, uint8_t test)
     mm->sect_offset++;
 
     if (verbose)
-	fprintf(logfp, "sun_load_table: Trying sector: %" PRIuDADDR "\n",
+	fprintf(stderr, "sun_load_table: Trying sector: %" PRIuDADDR "\n",
 		mm->sect_offset);
 
     if (mm_read_block_nobuf
