@@ -61,7 +61,7 @@
 #include <string.h>
 
 #include "tsk_os.h"
-#include "aux_lib.h"
+#include "libauxtools.h"
 
 
 /* Some platforms need to put stdin into binary mode, to read
